@@ -602,11 +602,11 @@ display_about (GUI *appGUI)
     gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, str, -1);
     g_free (str);
 
-#ifdef HAVE_GTKSPELL
-    str = g_strdup_printf ("     [+]\t%s (gtkspell)\n", _("Spell checker support"));
+#ifdef HAVE_GSPELL
+    str = g_strdup_printf ("     [+]\t%s (gspell)\n", _("Spell checker support"));
 #else
-    str = g_strdup_printf ("     [-]\t%s (gtkspell)\n", _("Spell checker support"));
-#endif  /* HAVE_GTKSPELL */
+    str = g_strdup_printf ("     [-]\t%s (gspell)\n", _("Spell checker support"));
+#endif  /* HAVE_GSPELL */
     gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, str, -1);
     g_free (str);
 
