@@ -141,8 +141,8 @@ gchar tmpbuf[BUFFER_SIZE], tmpbuf2[BUFFER_SIZE];
 				selected_date[idx].appGUI = appGUI;
 				g_signal_connect (G_OBJECT (appGUI->cal->calendar_buttons[idx]), "clicked",
 				                  G_CALLBACK (select_date_day_cb), &selected_date[idx]);
-				gtk_button_set_label (GTK_BUTTON (appGUI->cal->calendar_buttons[idx]), "");
-				gtk_label_set_markup (GTK_LABEL (GTK_BIN (appGUI->cal->calendar_buttons[idx])->child), tmpbuf);
+				GList *btnCh = gtk_container_get_children(GTK_CONTAINER (appGUI->cal->calendar_buttons[idx]));
+				gtk_label_set_markup (GTK_LABEL (btnCh->data), tmpbuf);
 				gtk_widget_show (appGUI->cal->calendar_buttons[idx]);
 
 			} else {
@@ -257,16 +257,16 @@ fullyear_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data
 	GUI *appGUI = (GUI *) user_data;
 
 	switch (event->keyval) {
-		case GDK_Escape:
+		case GDK_KEY_Escape:
 			gtk_widget_destroy (appGUI->cal->fullyear_window);
 			return TRUE;
-		case GDK_F1:
+		case GDK_KEY_F1:
 			g_signal_emit_by_name (G_OBJECT(appGUI->cal->fy_alternative_view_checkbutton), "clicked");
 			return TRUE;
-		case GDK_F2:
+		case GDK_KEY_F2:
 			year_info_cb (NULL, appGUI);
 			return TRUE;
-		case GDK_F3:
+		case GDK_KEY_F3:
 			change_to_current_year_cb (NULL, appGUI);
 			return TRUE;
 	}
@@ -320,7 +320,7 @@ GtkWidget   *close_button;
 GtkWidget   *hbox1;
 GtkWidget   *prev_button;
 GtkWidget   *info_button;
-GtkObject   *fy_spinbutton_adj;
+GtkAdjustment   *fy_spinbutton_adj;
 GtkWidget   *next_button;
 GtkWidget   *fycal_scrolledwindow;
 GtkWidget   *fycal_viewport;
@@ -351,11 +351,11 @@ gint rotate = FALSE;
 	g_signal_connect (G_OBJECT (appGUI->cal->fullyear_window), "key_press_event",
 	                  G_CALLBACK (fullyear_key_press_cb), appGUI);
 
-	vbox1 = gtk_vbox_new (FALSE, 0);
+	vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show (vbox1);
 	gtk_container_add (GTK_CONTAINER (appGUI->cal->fullyear_window), vbox1);
 
-	hbox1 = gtk_hbox_new (FALSE, 0);
+	hbox1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_show (hbox1);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 4);
 
@@ -364,7 +364,8 @@ gint rotate = FALSE;
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (hbox1), label, FALSE, TRUE, 0);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_misc_set_padding (GTK_MISC (label), 0, 4);
+        gtk_widget_set_margin_top (label, 4);
+        gtk_widget_set_margin_bottom (label, 4);
 
 	fy_spinbutton_adj = gtk_adjustment_new (utl_date_get_current_year (), JULIAN_GREGORIAN_YEAR, 9999, 1, 10, 0);
 	appGUI->cal->fy_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (fy_spinbutton_adj), 1, 0);
@@ -375,8 +376,8 @@ gint rotate = FALSE;
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton), TRUE);
 	gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton), GTK_UPDATE_IF_VALID);
 
-	info_button = utl_gui_create_button (GTK_STOCK_INFO, OSMO_STOCK_BUTTON_INFO, FALSE);
-	GTK_WIDGET_UNSET_FLAGS(info_button, GTK_CAN_FOCUS);
+	info_button = gtk_button_new_from_icon_name ("dialog-information", GTK_ICON_SIZE_BUTTON);
+	gtk_widget_set_can_focus(info_button, FALSE);
 	gtk_widget_show (info_button);
 	g_signal_connect (info_button, "clicked", G_CALLBACK (year_info_cb), appGUI);
 	if (config.enable_tooltips) {
@@ -385,12 +386,12 @@ gint rotate = FALSE;
 	gtk_button_set_relief (GTK_BUTTON (info_button), GTK_RELIEF_NONE);
 	gtk_box_pack_start (GTK_BOX (hbox1), info_button, FALSE, FALSE, 2);
 
-	vseparator = gtk_vseparator_new ();
+	vseparator = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
 	gtk_widget_show (vseparator);
 	gtk_box_pack_start (GTK_BOX (hbox1), vseparator, FALSE, FALSE, 8);
 
-	prev_button = utl_gui_create_button (GTK_STOCK_GO_BACK, OSMO_STOCK_BUTTON_PREV_YEAR, FALSE);
-	GTK_WIDGET_UNSET_FLAGS (prev_button, GTK_CAN_FOCUS);
+	prev_button = gtk_button_new_from_icon_name ("go-previous", GTK_ICON_SIZE_BUTTON);
+	gtk_widget_set_can_focus (prev_button, FALSE);
 	gtk_widget_show (prev_button);
 	g_signal_connect (prev_button, "clicked", G_CALLBACK (change_to_previous_year_cb), appGUI);
 	if (config.enable_tooltips) {
@@ -399,8 +400,8 @@ gint rotate = FALSE;
 	gtk_button_set_relief (GTK_BUTTON (prev_button), GTK_RELIEF_NONE);
 	gtk_box_pack_start (GTK_BOX (hbox1), prev_button, FALSE, FALSE, 2);
 
-	appGUI->cal->cyear_button = utl_gui_create_button (GTK_STOCK_HOME, OSMO_STOCK_BUTTON_TODAY, FALSE);
-	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->cyear_button, GTK_CAN_FOCUS);
+	appGUI->cal->cyear_button = gtk_button_new_from_icon_name ("go-home", GTK_ICON_SIZE_BUTTON);
+	gtk_widget_set_can_focus (appGUI->cal->cyear_button, FALSE);
 	gtk_widget_show (appGUI->cal->cyear_button);
 	g_signal_connect (appGUI->cal->cyear_button, "clicked", G_CALLBACK (change_to_current_year_cb), appGUI);
 	if (config.enable_tooltips) {
@@ -409,8 +410,8 @@ gint rotate = FALSE;
 	gtk_button_set_relief (GTK_BUTTON (appGUI->cal->cyear_button), GTK_RELIEF_NONE);
 	gtk_box_pack_start (GTK_BOX (hbox1), appGUI->cal->cyear_button, FALSE, FALSE, 2);
 
-	next_button = utl_gui_create_button (GTK_STOCK_GO_FORWARD, OSMO_STOCK_BUTTON_NEXT_YEAR, FALSE);
-	GTK_WIDGET_UNSET_FLAGS(next_button, GTK_CAN_FOCUS);
+	next_button = gtk_button_new_from_icon_name ("go-next", GTK_ICON_SIZE_BUTTON);
+	gtk_widget_set_can_focus(next_button, FALSE);
 	gtk_widget_show (next_button);
 	g_signal_connect (next_button, "clicked", G_CALLBACK (change_to_next_year_cb), appGUI);
 	if (config.enable_tooltips) {
@@ -419,12 +420,12 @@ gint rotate = FALSE;
 	gtk_button_set_relief (GTK_BUTTON (next_button), GTK_RELIEF_NONE);
 	gtk_box_pack_start (GTK_BOX (hbox1), next_button, FALSE, FALSE, 2);
 
-	vseparator = gtk_vseparator_new ();
+	vseparator = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
 	gtk_widget_show (vseparator);
 	gtk_box_pack_start (GTK_BOX (hbox1), vseparator, FALSE, FALSE, 8);
 
 	appGUI->cal->fy_alternative_view_checkbutton = gtk_check_button_new_with_mnemonic (_("Alternative view"));
-	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->fy_alternative_view_checkbutton, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (appGUI->cal->fy_alternative_view_checkbutton, FALSE);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->cal->fy_alternative_view_checkbutton), config.fy_alternative_view);
 	g_signal_connect (G_OBJECT (appGUI->cal->fy_alternative_view_checkbutton), "toggled",
 	                  G_CALLBACK (alternative_view_cb), appGUI);
@@ -441,76 +442,63 @@ gint rotate = FALSE;
 	gtk_widget_show (fycal_viewport);
 	gtk_container_add (GTK_CONTAINER (fycal_scrolledwindow), fycal_viewport);
 
-	vbox2 = gtk_vbox_new (FALSE, 0);
+	vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show (vbox2);
 	gtk_container_add (GTK_CONTAINER (fycal_viewport), vbox2);
 
 	/*-------------------------------------------------------------------------------------*/
 	/* First view */
 
-	if (config.fy_simple_view == TRUE) {
-		appGUI->cal->fycal_table_1 = gtk_table_new (MAX_MONTHS + 2, FULL_YEAR_COLS + 1, FALSE);
-	} else {
-		appGUI->cal->fycal_table_1 = gtk_table_new (MAX_MONTHS + 4, FULL_YEAR_COLS + 3, FALSE);
-	}
+	appGUI->cal->fycal_table_1 = gtk_grid_new ();
 
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->cal->fy_alternative_view_checkbutton)) == FALSE) {
 		gtk_widget_show (appGUI->cal->fycal_table_1);
 	}
 	gtk_box_pack_start (GTK_BOX (vbox2), appGUI->cal->fycal_table_1, TRUE, TRUE, 0);
 
-	vseparator = gtk_vseparator_new ();
+	vseparator = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
 	gtk_widget_show (vseparator);
+        gtk_widget_set_hexpand(vseparator, TRUE);
+        gtk_widget_set_vexpand(vseparator, TRUE);
 	if (config.fy_simple_view == TRUE) {
-		gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table_1), vseparator, 1, 2, 0, 14,
-		                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
+		gtk_grid_attach (GTK_GRID (appGUI->cal->fycal_table_1), vseparator, 1, 0, 1, 14);
 	} else {
-		gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table_1), vseparator, 1, 2, 0, 16,
-		                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
+		gtk_grid_attach (GTK_GRID (appGUI->cal->fycal_table_1), vseparator, 1, 0, 1, 16);
 	}
 
-	hseparator = gtk_hseparator_new ();
+	hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_widget_show (hseparator);
-	gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table_1), hseparator, 2, 39, 1, 2,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-	                  (GtkAttachOptions) (GTK_FILL), 0, 0);
+	gtk_widget_set_hexpand(hseparator, TRUE);
+	gtk_grid_attach (GTK_GRID (appGUI->cal->fycal_table_1), hseparator, 2, 1, 37, 1);
 
-	hseparator = gtk_hseparator_new ();
+	hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_widget_show (hseparator);
-	gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table_1), hseparator, 0, 1, 1, 2,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-	                  (GtkAttachOptions) (GTK_FILL), 0, 0);
+	gtk_widget_set_hexpand(hseparator, TRUE);
+	gtk_grid_attach (GTK_GRID (appGUI->cal->fycal_table_1), hseparator, 0, 1, 1, 1);
 
 	if (config.fy_simple_view == FALSE) {
 
-		vseparator = gtk_vseparator_new ();
+		vseparator = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
 		gtk_widget_show (vseparator);
-		gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table_1), vseparator, FULL_YEAR_COLS + 2, FULL_YEAR_COLS + 3, 0, 16,
-		                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
-		hseparator = gtk_hseparator_new ();
+		gtk_widget_set_hexpand(vseparator, TRUE);
+		gtk_widget_set_vexpand(vseparator, TRUE);
+		gtk_grid_attach (GTK_GRID (appGUI->cal->fycal_table_1), vseparator, FULL_YEAR_COLS + 2, 0, 1, 16);
+		hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
 		gtk_widget_show (hseparator);
-		gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table_1), hseparator, 2, 39, MAX_MONTHS + 2, MAX_MONTHS + 3,
-		                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		                  (GtkAttachOptions) (GTK_FILL), 0, 0);
-		hseparator = gtk_hseparator_new ();
+		gtk_widget_set_hexpand(hseparator, TRUE);
+		gtk_grid_attach (GTK_GRID (appGUI->cal->fycal_table_1), hseparator, 2, MAX_MONTHS + 2, 37, 1);
+		hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
 		gtk_widget_show (hseparator);
-		gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table_1), hseparator, 0, 1, MAX_MONTHS + 2, MAX_MONTHS + 3,
-		                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		                  (GtkAttachOptions) (GTK_FILL), 0, 0);
-		hseparator = gtk_hseparator_new ();
+		gtk_widget_set_hexpand(hseparator, TRUE);
+		gtk_grid_attach (GTK_GRID (appGUI->cal->fycal_table_1), hseparator, 0, MAX_MONTHS + 2, 1, 1);
+		hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
 		gtk_widget_show (hseparator);
-		gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table_1), hseparator, FULL_YEAR_COLS + 3, FULL_YEAR_COLS + 4, 1, 2,
-		                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		                  (GtkAttachOptions) (GTK_FILL), 0, 0);
-		hseparator = gtk_hseparator_new ();
+		gtk_widget_set_hexpand(hseparator, TRUE);
+		gtk_grid_attach (GTK_GRID (appGUI->cal->fycal_table_1), hseparator, FULL_YEAR_COLS + 3, 1, 1, 1);
+		hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
 		gtk_widget_show (hseparator);
-		gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table_1), hseparator, FULL_YEAR_COLS + 3, FULL_YEAR_COLS + 4,
-		                  MAX_MONTHS + 2, MAX_MONTHS + 3,
-		                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		                  (GtkAttachOptions) (GTK_FILL), 0, 0);
+		gtk_widget_set_hexpand(hseparator, TRUE);
+		gtk_grid_attach (GTK_GRID (appGUI->cal->fycal_table_1), hseparator, FULL_YEAR_COLS + 3, MAX_MONTHS + 2, 1, 1);
 	}
 
 	g_date_set_day (cdate, 1);
@@ -523,22 +511,18 @@ gint rotate = FALSE;
 
 		label = gtk_label_new (NULL);
 		gtk_widget_show (label);
-		gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table_1), label, 0, 1, month + 1, month + 2,
-		                  (GtkAttachOptions) (GTK_FILL),
-		                  (GtkAttachOptions) (0), 0, 0);
+		gtk_grid_attach (GTK_GRID (appGUI->cal->fycal_table_1), label, 0, month + 1, 1, 1);
 
-		gtk_misc_set_padding (GTK_MISC (label), 8, 0);
+        gtk_widget_set_margin_left (label, 8);
+        gtk_widget_set_margin_right (label, 8);
 		gtk_label_set_markup (GTK_LABEL (label), tmpbuf);
 
 		if (config.fy_simple_view == FALSE) {
 			label = gtk_label_new (NULL);
 			gtk_widget_show (label);
-			gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table_1), label,
-			                  FULL_YEAR_COLS + 3, FULL_YEAR_COLS + 4, month + 1, month + 2,
-			                  (GtkAttachOptions) (GTK_FILL),
-			                  (GtkAttachOptions) (0), 0, 0);
-
-			gtk_misc_set_padding (GTK_MISC (label), 8, 0);
+			gtk_grid_attach (GTK_GRID (appGUI->cal->fycal_table_1), label, FULL_YEAR_COLS + 3, month + 1, 1, 1);
+            gtk_widget_set_margin_left (label, 8);
+            gtk_widget_set_margin_right (label, 8);
 			gtk_label_set_markup (GTK_LABEL (label), tmpbuf);
 		}
 	}
@@ -560,10 +544,9 @@ gint rotate = FALSE;
 
 		label = gtk_label_new (NULL);
 		gtk_widget_show (label);
-		gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table_1), label, i + 2, i + 3, 0, 1,
-		                  (GtkAttachOptions) (GTK_FILL),
-		                  (GtkAttachOptions) (0), 0, 0);
-		gtk_misc_set_padding (GTK_MISC (label), 4, 0);
+		gtk_grid_attach (GTK_GRID (appGUI->cal->fycal_table_1), label, i + 2, 0, 1, 1);
+        gtk_widget_set_margin_left (label, 4);
+        gtk_widget_set_margin_right (label, 4);
 		if (rotate)
 			gtk_label_set_angle (GTK_LABEL (label), 90);
 		gtk_label_set_markup (GTK_LABEL (label), tmpbuf);
@@ -571,10 +554,9 @@ gint rotate = FALSE;
 		if (config.fy_simple_view == FALSE) {
 			label = gtk_label_new (NULL);
 			gtk_widget_show (label);
-			gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table_1), label, i + 2, i + 3, MAX_MONTHS + 3, MAX_MONTHS + 4,
-			                  (GtkAttachOptions) (GTK_FILL),
-			                  (GtkAttachOptions) (0), 0, 0);
-			gtk_misc_set_padding (GTK_MISC (label), 4, 0);
+			gtk_grid_attach (GTK_GRID (appGUI->cal->fycal_table_1), label, i + 2, MAX_MONTHS + 3, 1, 1);
+            gtk_widget_set_margin_left (label, 4);
+            gtk_widget_set_margin_right (label, 4);
 			if (rotate)
 				gtk_label_set_angle (GTK_LABEL (label), 90);
 			gtk_label_set_markup (GTK_LABEL (label), tmpbuf);
@@ -588,13 +570,11 @@ gint rotate = FALSE;
 			i = month - 1;
 			idx = i * FULL_YEAR_COLS + j;
 
-			appGUI->cal->calendar_buttons[idx] = gtk_button_new ();
-			GTK_WIDGET_UNSET_FLAGS (appGUI->cal->calendar_buttons[idx], GTK_CAN_FOCUS);
+			appGUI->cal->calendar_buttons[idx] = gtk_button_new_with_label ("");
+			gtk_widget_set_can_focus (appGUI->cal->calendar_buttons[idx], FALSE);
 			gtk_button_set_relief (GTK_BUTTON (appGUI->cal->calendar_buttons[idx]), GTK_RELIEF_NONE);
 			gtk_widget_show (appGUI->cal->calendar_buttons[idx]);
-			gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table_1), appGUI->cal->calendar_buttons[idx], j+2, j+3, i+2, i+3,
-			                  (GtkAttachOptions) (GTK_FILL),
-			                  (GtkAttachOptions) (0), 0, 0);
+			gtk_grid_attach (GTK_GRID (appGUI->cal->fycal_table_1), appGUI->cal->calendar_buttons[idx], j+2, i+2, 1, 1);
 		}
 	}
 
@@ -604,7 +584,7 @@ gint rotate = FALSE;
 	/*-------------------------------------------------------------------------------------*/
 	/* Second view */
 
-	appGUI->cal->fycal_table_2 = gtk_table_new (3, 4, FALSE);
+	appGUI->cal->fycal_table_2 = gtk_grid_new ();
 
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->cal->fy_alternative_view_checkbutton)) == TRUE) {
 		gtk_widget_show (appGUI->cal->fycal_table_2);
@@ -615,11 +595,10 @@ gint rotate = FALSE;
 
 		for (x = 0; x < 4; x++, i++) {
 
-			fycal_vbox = gtk_vbox_new (FALSE, 0);
+			fycal_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 			gtk_widget_show (fycal_vbox);
-			gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table_2), fycal_vbox, x, x + 1, y, y + 1,
-			                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
-			                  (GtkAttachOptions) (0), 0, 0);
+                        gtk_widget_set_hexpand(fycal_vbox, TRUE);
+			gtk_grid_attach (GTK_GRID (appGUI->cal->fycal_table_2), fycal_vbox, x, y, 1, 1);
 			fycal_label = gtk_label_new (NULL);
 			gtk_widget_show (fycal_label);
 			gtk_box_pack_start (GTK_BOX (fycal_vbox), fycal_label, FALSE, FALSE, 0);
@@ -627,20 +606,12 @@ gint rotate = FALSE;
 			g_signal_connect (appGUI->cal->fy_calendars[i], 
 							  "day_selected_double_click", G_CALLBACK (calendar_dbclick_cb), appGUI);
 			gtk_widget_show (appGUI->cal->fy_calendars[i]);
-			GTK_WIDGET_UNSET_FLAGS (appGUI->cal->fy_calendars[i], GTK_CAN_FOCUS);
+			gtk_widget_set_can_focus (appGUI->cal->fy_calendars[i], FALSE);
 			gui_calendar_set_display_options (GUI_CALENDAR (appGUI->cal->fy_calendars[i]),
 			                                  (config.display_options & (GUI_CALENDAR_SHOW_DAY_NAMES |
 			                                  GUI_CALENDAR_WEEK_START_MONDAY)) | GUI_CALENDAR_NO_MONTH_CHANGE);
 			gui_calendar_enable_cursor (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), FALSE);
-			gui_calendar_set_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.mark_color, 0, EVENT_MARKER_COLOR);
-			gui_calendar_set_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.selection_color, 0, SELECTOR_COLOR);
-			gui_calendar_set_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.header_color, 0, HEADER_COLOR);
-			gui_calendar_set_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.weekend_color, 0, WEEKEND_COLOR);
-			gui_calendar_set_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.mark_current_day_color, config.mark_current_day_alpha, TODAY_MARKER_COLOR);
-            gui_calendar_set_color (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.birthday_mark_color, 0, BIRTHDAY_MARKER_COLOR);
-			gui_calendar_set_day_note_marker_symbol (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.day_note_marker);
-			gui_calendar_set_marker (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.today_marker_type, TODAY_MARKER);
-			gui_calendar_set_marker (GUI_CALENDAR (appGUI->cal->fy_calendars[i]), config.event_marker_type, EVENT_MARKER);
+            gui_set_calendar_defaults(appGUI->cal->fy_calendars[i]);
 
 			year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton));
 			month = i + 1;
@@ -662,17 +633,17 @@ gint rotate = FALSE;
 
 	/*-------------------------------------------------------------------------------------*/
 
-	hseparator = gtk_hseparator_new ();
+	hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_widget_show (hseparator);
 	gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 4);
 
-	hbuttonbox = gtk_hbutton_box_new ();
+	hbuttonbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_widget_show (hbuttonbox);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, TRUE, 0);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-	close_button = utl_gui_create_labeled_button (GTK_STOCK_CLOSE, OSMO_STOCK_BUTTON_CLOSE, _("Close"));
+	close_button = gtk_button_new_with_mnemonic (_("_Close"));
 	gtk_widget_show (close_button);
 	g_signal_connect (close_button, "clicked", G_CALLBACK (button_fullyear_window_close_cb), appGUI);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), close_button);
