@@ -61,7 +61,7 @@ jumpto_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
 
-    if (event->keyval == GDK_Escape) {
+    if (event->keyval == GDK_KEY_Escape) {
             jumpto_window_close_cb (NULL, NULL, appGUI);
             return TRUE;
     }
@@ -79,7 +79,7 @@ gint a;
 
     GUI *appGUI = (GUI *)data;
 
-    if (event->keyval == GDK_Return) {
+    if (event->keyval == GDK_KEY_Return) {
 
         if (check_number(gtk_entry_get_text(GTK_ENTRY(appGUI->cal->day_entry))) == FALSE) {
             g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_date_get_current_day ());
@@ -110,7 +110,7 @@ gint a;
 
     GUI *appGUI = (GUI *)data;
 
-    if (event->keyval == GDK_Return) {
+    if (event->keyval == GDK_KEY_Return) {
 
         if (check_number(gtk_entry_get_text(GTK_ENTRY(appGUI->cal->month_entry))) == FALSE) {
             g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_date_get_current_month ());
@@ -132,7 +132,7 @@ gint a;
 }
 
 /*------------------------------------------------------------------------------*/
-/* FIXME */
+
 void
 jumpto_go_window_close_cb (GtkButton *button, gpointer user_data)
 {
@@ -176,7 +176,7 @@ year_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
 
-    if (event->keyval == GDK_Return) {
+    if (event->keyval == GDK_KEY_Return) {
 
         jumpto_go_window_close_cb (NULL, appGUI); 
         return TRUE;
@@ -197,7 +197,7 @@ GtkWidget   *hbuttonbox;
 GtkWidget   *cancel_button;
 GtkWidget   *jumpto_button;
 gint        win_xpos, win_ypos;
-char tmpbuf[BUFFER_SIZE];
+gchar       tmpbuf[BUFFER_SIZE];
 
     appGUI->cal->jumpto_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
     gtk_window_set_title (GTK_WINDOW (appGUI->cal->jumpto_window), _("Jump to date"));
@@ -213,52 +213,51 @@ char tmpbuf[BUFFER_SIZE];
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->cal->jumpto_window), 8);
     gtk_window_set_resizable (GTK_WINDOW (appGUI->cal->jumpto_window), FALSE);
 
-    vbox1 = gtk_vbox_new (FALSE, 0);
+    vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_widget_show (vbox1);
     gtk_container_add (GTK_CONTAINER (appGUI->cal->jumpto_window), vbox1);
 
-    hbox1 = gtk_hbox_new (FALSE, 0);
+    hbox1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_widget_show (hbox1);
     gtk_box_pack_start (GTK_BOX (vbox1), hbox1, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (hbox1), 6);
 
-    sprintf(tmpbuf, "%s:", _("Day"));
+    g_snprintf(tmpbuf, BUFFER_SIZE, "%s:", _("Day"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (hbox1), label, FALSE, FALSE, 0);
-    gtk_misc_set_padding (GTK_MISC (label), 8, 0);
+    gtk_widget_set_margin_right (label, 8);
 
     appGUI->cal->day_entry = gtk_entry_new ();
     gtk_widget_show (appGUI->cal->day_entry);
-    gtk_widget_set_size_request (appGUI->cal->day_entry, 50, -1);
     gtk_entry_set_max_length (GTK_ENTRY(appGUI->cal->day_entry), 2);
     g_signal_connect (G_OBJECT (appGUI->cal->day_entry), "key_press_event",
                         G_CALLBACK (day_key_press_cb), appGUI);
     gtk_box_pack_start (GTK_BOX (hbox1), appGUI->cal->day_entry, FALSE, TRUE, 1);
 
-    sprintf(tmpbuf, "%s:", _("Month"));
+    g_snprintf(tmpbuf, BUFFER_SIZE, "%s:", _("Month"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (hbox1), label, FALSE, FALSE, 0);
-    gtk_misc_set_padding (GTK_MISC (label), 8, 0);
+    gtk_widget_set_margin_left (label, 8);
+    gtk_widget_set_margin_right (label, 8);
 
     appGUI->cal->month_entry = gtk_entry_new ();
     gtk_widget_show (appGUI->cal->month_entry);
-    gtk_widget_set_size_request (appGUI->cal->month_entry, 50, -1);
     gtk_entry_set_max_length (GTK_ENTRY(appGUI->cal->month_entry), 2);
     g_signal_connect (G_OBJECT (appGUI->cal->month_entry), "key_press_event",
                         G_CALLBACK (month_key_press_cb), appGUI);
     gtk_box_pack_start (GTK_BOX (hbox1), appGUI->cal->month_entry, FALSE, TRUE, 1);
 
-    sprintf(tmpbuf, "%s:", _("Year"));
+    g_snprintf(tmpbuf, BUFFER_SIZE, "%s:", _("Year"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (hbox1), label, FALSE, FALSE, 0);
-    gtk_misc_set_padding (GTK_MISC (label), 8, 0);
+    gtk_widget_set_margin_left (label, 8);
+    gtk_widget_set_margin_right (label, 8);
 
     appGUI->cal->year_entry = gtk_entry_new ();
     gtk_widget_show (appGUI->cal->year_entry);
-    gtk_widget_set_size_request (appGUI->cal->year_entry, 50, -1);
     gtk_entry_set_max_length (GTK_ENTRY(appGUI->cal->year_entry), 4);
     g_signal_connect (G_OBJECT (appGUI->cal->year_entry), "key_press_event",
                         G_CALLBACK (year_key_press_cb), appGUI);
@@ -271,22 +270,22 @@ char tmpbuf[BUFFER_SIZE];
 	g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_date_get_current_year ());
 	gtk_entry_set_text (GTK_ENTRY (appGUI->cal->year_entry), tmpbuf);
 
-    hseparator = gtk_hseparator_new ();
+    hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show (hseparator);
     gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 4);
 
-    hbuttonbox = gtk_hbutton_box_new ();
+    hbuttonbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show (hbuttonbox);
     gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, TRUE, 0);
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-	cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
+	cancel_button = gtk_button_new_with_mnemonic (_("_Cancel"));
     gtk_widget_show (cancel_button);
     g_signal_connect(cancel_button, "clicked", G_CALLBACK(button_jumpto_window_close_cb), appGUI);
     gtk_container_add(GTK_CONTAINER(hbuttonbox), cancel_button);
 
-	jumpto_button = utl_gui_create_labeled_button (GTK_STOCK_JUMP_TO, OSMO_STOCK_BUTTON_JUMPTO, _("Jump to"));
+	jumpto_button = gtk_button_new_with_mnemonic (_("_Jump to"));
     gtk_widget_show (jumpto_button);
     g_signal_connect(jumpto_button, "clicked", G_CALLBACK(jumpto_go_window_close_cb), appGUI);
     gtk_container_add(GTK_CONTAINER(hbuttonbox), jumpto_button);
