@@ -1573,15 +1573,11 @@ calendar_options_cb (GtkToggleButton *togglebutton, GUI *appGUI)
 		}
 	}
 
-#ifdef HAVE_GTKSPELL
+#ifdef HAVE_GSPELL
 	config.day_note_spell_checker = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->spell_checker_in_day_notes_checkbutton));
 
-        if (config.day_note_spell_checker == TRUE) {
-            utl_gui_attach_spell_check(GTK_TEXT_VIEW(appGUI->cal->calendar_note_textview));
-        } else {
-            utl_gui_dettach_spell_check(GTK_TEXT_VIEW(appGUI->cal->calendar_note_textview));
-        }
-#endif /* HAVE_GTKSPELL */
+        utl_gui_set_enable_spell_check(appGUI->cal->calendar_note_spelltextview, config.day_note_spell_checker);
+#endif /* HAVE_GSPELL */
 
 	gui_calendar_set_display_options (GUI_CALENDAR (appGUI->cal->calendar_prev),
 	    (config.display_options & (GUI_CALENDAR_SHOW_DAY_NAMES | GUI_CALENDAR_WEEK_START_MONDAY)) | GUI_CALENDAR_NO_MONTH_CHANGE);
@@ -1673,14 +1669,14 @@ create_options_section (GtkWidget *calendar_opt_vbox, GUI *appGUI)
 	appGUI->opt->ascending_sorting_in_day_notes_checkbutton = checkbutton;
 
 	i++;
-#ifdef HAVE_GTKSPELL
-	checkbutton = gtk_check_button_new_with_mnemonic (_("Enable spell checker in day notes"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.day_note_spell_checker);
+#ifdef HAVE_GSPELL
+    checkbutton = gtk_check_button_new_with_mnemonic(_("Enable spell checker in day notes"));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton), config.day_note_spell_checker);
     gtk_widget_set_hexpand(checkbutton, TRUE);
-	gtk_grid_attach (GTK_GRID (table), checkbutton, 0, i, 1, 1);
-	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (calendar_options_cb), appGUI);
-	appGUI->opt->spell_checker_in_day_notes_checkbutton = checkbutton;
-#endif /* HAVE_GTKSPELL */
+    gtk_grid_attach(GTK_GRID(table), checkbutton, 0, i, 1, 1);
+    g_signal_connect(G_OBJECT(checkbutton), "toggled", G_CALLBACK(calendar_options_cb), appGUI);
+    appGUI->opt->spell_checker_in_day_notes_checkbutton = checkbutton;
+#endif /* HAVE_GSPELL */
 }
 
 /* ========================================================================== */
