@@ -22,7 +22,7 @@
 #ifndef _CALENDAR_INSERT_TIMELINE_H
 #define _CALENDAR_INSERT_TIMELINE_H
 
-#include "gui.h"
+#include "utils_gui.h"
 
 void    calendar_create_insert_timeline_window  (GUI *appGUI);
 
