@@ -61,7 +61,7 @@ birthdays_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_dat
 {
 	switch (event->keyval) {
 
-		case GDK_Escape:
+		case GDK_KEY_Escape:
 	        birthdays_window_close_cb (NULL, NULL, user_data);
 			return TRUE;
 
@@ -192,7 +192,7 @@ gboolean flag, leap;
 	g_signal_connect (G_OBJECT (appGUI->cnt->birthdays_window), "key_press_event",
 	                  G_CALLBACK (birthdays_key_press_cb), appGUI);
 
-	vbox1 = gtk_vbox_new (FALSE, 0);
+	vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show (vbox1);
 	gtk_container_add (GTK_CONTAINER (appGUI->cnt->birthdays_window), vbox1);
 
@@ -208,9 +208,8 @@ gboolean flag, leap;
 	                                                        G_TYPE_INT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT);
 
 	appGUI->cnt->birthdays_list = gtk_tree_view_new_with_model (GTK_TREE_MODEL (appGUI->cnt->birthdays_list_store));
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (appGUI->cnt->birthdays_list), config.rules_hint);
 	gtk_widget_show (appGUI->cnt->birthdays_list);
-	GTK_WIDGET_SET_FLAGS (appGUI->cnt->birthdays_list, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (appGUI->cnt->birthdays_list, TRUE);
 	gtk_container_add (GTK_CONTAINER (scrolledwindow), appGUI->cnt->birthdays_list);
 
 	appGUI->cnt->birthdays_list_selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (appGUI->cnt->birthdays_list));
@@ -349,17 +348,17 @@ gboolean flag, leap;
 	g_date_free (cdate_birthday);
 	g_date_free (cdate_current);
 
-	hseparator = gtk_hseparator_new ();
+	hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_widget_show (hseparator);
 	gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 4);
 
-	hbuttonbox = gtk_hbutton_box_new ();
+	hbuttonbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_widget_show (hbuttonbox);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, TRUE, 0);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-	close_button = utl_gui_create_labeled_button (GTK_STOCK_CLOSE, OSMO_STOCK_BUTTON_CLOSE, _("Close"));
+	close_button = gtk_button_new_with_mnemonic (_("_Close"));
 	gtk_widget_show (close_button);
 	g_signal_connect (close_button, "clicked", G_CALLBACK (button_birthdays_window_close_cb), appGUI);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), close_button);
