@@ -26,8 +26,11 @@
 
 enum {     
     B_COLUMN_NAME = 0,
+    B_COLUMN_DAYS_NUM,
     B_COLUMN_DAYS,
     B_COLUMN_AGE,
+    B_COLUMN_DATE,
+    B_COLUMN_ZODIAC,
     B_COLUMN_ID,
     BIRTHDAYS_NUM_COLUMNS
 };
