@@ -41,16 +41,8 @@ GtkWidget *dialog;
 GtkFileFilter *filter_1, *filter_2;
 gboolean ret = FALSE;
 
-    dialog = gtk_file_chooser_dialog_new(_("Select CSV file"),
-                                         GTK_WINDOW(appGUI->cnt->import_sel_window),
-                                         GTK_FILE_CHOOSER_ACTION_OPEN,
-                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                         GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-                                         NULL);
-
-    gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
-    gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(dialog), FALSE);
-    gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);
+    dialog = utl_gui_create_open_file_dialog(_("Select CSV file"),
+                                         GTK_WINDOW(appGUI->main_window));
 
     filter_1 = gtk_file_filter_new();
     gtk_file_filter_add_pattern(filter_1, "*");
@@ -92,7 +84,7 @@ import_sel_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_da
 
     GUI *appGUI = (GUI *)user_data;
 
-    gdk_window_get_root_origin (GDK_WINDOW(appGUI->cnt->import_sel_window->window),
+    gdk_window_get_root_origin (gtk_widget_get_window(appGUI->cnt->import_sel_window),
                                 &config.contacts_import_sel_win_x, &config.contacts_import_sel_win_y);
 
 /*    import_store_values (appGUI);*/
@@ -108,7 +100,7 @@ import_sel_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
     GUI *appGUI = (GUI *)data;
 
     switch(event->keyval) {
-        case GDK_Escape:
+        case GDK_KEY_Escape:
             import_sel_window_close_cb (widget, NULL, appGUI);
             return TRUE;
     }
@@ -176,7 +168,7 @@ import_sel_cb (GtkWidget *widget, gpointer user_data) {
         text = (gchar *)gtk_entry_get_text (GTK_ENTRY(appGUI->cnt->input_file_entry));
 
         if (!strlen(text)) {
-            sprintf (tmpbuf, "%s", _("Please select file first."));
+            g_snprintf(tmpbuf, BUFFER_SIZE, "%s", _("Please select file first."));
             utl_gui_create_dialog (GTK_MESSAGE_ERROR, tmpbuf, GTK_WINDOW(appGUI->cnt->import_sel_window));
             return;
         }
@@ -196,7 +188,6 @@ GtkWidget *hseparator;
 GtkWidget *hbox1;
 GtkWidget *label;
 GtkWidget *frame;
-GtkWidget *alignment;
 GtkWidget *hbox4;
 GtkWidget *vbox4;
 GtkWidget *hbox6;
@@ -224,38 +215,38 @@ gchar tmpbuf[BUFFER_SIZE];
     g_signal_connect (G_OBJECT (appGUI->cnt->import_sel_window), "delete_event", 
                       G_CALLBACK(import_sel_window_close_cb), appGUI);
 
-    vbox1 = gtk_vbox_new (FALSE, 0);
+    vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_widget_show (vbox1);
     gtk_container_add (GTK_CONTAINER (appGUI->cnt->import_sel_window), vbox1);
 
-    hseparator = gtk_hseparator_new ();
+    hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show (hseparator);
     gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, FALSE, 4);
 
-    hbox1 = gtk_hbox_new (FALSE, 0);
+    hbox1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_widget_show (hbox1);
     gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 0);
 
-    sprintf (tmpbuf, "%s:", _("Import type"));
+    g_snprintf(tmpbuf, BUFFER_SIZE, "%s:", _("Import type"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (hbox1), label, FALSE, FALSE, 5);
 
-    appGUI->cnt->import_type_combobox = gtk_combo_box_new_text ();
+    appGUI->cnt->import_type_combobox = gtk_combo_box_text_new ();
     gtk_widget_show (appGUI->cnt->import_type_combobox);
     gtk_box_pack_start (GTK_BOX (hbox1), appGUI->cnt->import_type_combobox, FALSE, FALSE, 8);
-    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->cnt->import_type_combobox), _("File"));
-    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->cnt->import_type_combobox), "SyncML");
+    gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (appGUI->cnt->import_type_combobox), NULL, _("File"));
+    gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (appGUI->cnt->import_type_combobox), NULL, "SyncML");
     g_signal_connect (G_OBJECT (appGUI->cnt->import_type_combobox), "changed",
                       G_CALLBACK (import_type_selected_cb), appGUI);
     g_signal_connect(G_OBJECT(appGUI->cnt->import_type_combobox), "focus",
                      G_CALLBACK(import_sel_combo_box_focus_cb), appGUI);
 
-    hseparator = gtk_hseparator_new ();
+    hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show (hseparator);
     gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 4);
 
-    appGUI->cnt->file_import_vbox = gtk_vbox_new (FALSE, 0);
+    appGUI->cnt->file_import_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_widget_show (appGUI->cnt->file_import_vbox);
     gtk_box_pack_start (GTK_BOX (vbox1), appGUI->cnt->file_import_vbox, FALSE, FALSE, 0);
 
@@ -264,33 +255,29 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_box_pack_start (GTK_BOX (appGUI->cnt->file_import_vbox), frame, FALSE, FALSE, 0);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_widget_show (alignment);
-    gtk_container_add (GTK_CONTAINER (frame), alignment);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
-    hbox4 = gtk_hbox_new (FALSE, 0);
+    hbox4 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_widget_show (hbox4);
-    gtk_container_add (GTK_CONTAINER (alignment), hbox4);
+    gtk_widget_set_margin_left(hbox4, 12);
+    gtk_container_add (GTK_CONTAINER (frame), hbox4);
 
     appGUI->cnt->input_file_entry = gtk_entry_new ();
     gtk_widget_show (appGUI->cnt->input_file_entry);
     gtk_box_pack_start (GTK_BOX (hbox4), appGUI->cnt->input_file_entry, TRUE, TRUE, 0);
-    GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->input_file_entry, GTK_CAN_FOCUS);
+    gtk_widget_set_can_focus(appGUI->cnt->input_file_entry, FALSE);
     gtk_editable_set_editable (GTK_EDITABLE(appGUI->cnt->input_file_entry), FALSE);
 
-	appGUI->cnt->contacts_browse_button = utl_gui_create_labeled_button (GTK_STOCK_OPEN, OSMO_STOCK_BUTTON_OPEN, _("Browse"));
-    GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->contacts_browse_button, GTK_CAN_FOCUS);
+	appGUI->cnt->contacts_browse_button = gtk_button_new_with_mnemonic (_("_Open"));
+    gtk_widget_set_can_focus(appGUI->cnt->contacts_browse_button, FALSE);
     gtk_widget_show (appGUI->cnt->contacts_browse_button);
     gtk_box_pack_start (GTK_BOX (hbox4), appGUI->cnt->contacts_browse_button, FALSE, TRUE, 4);
 
-    sprintf (tmpbuf, "<b>%s:</b>", _("Input filename"));
+    g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Input filename"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-    appGUI->cnt->import_vbox = gtk_vbox_new (FALSE, 0);
+    appGUI->cnt->import_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_widget_show (appGUI->cnt->import_vbox);
     gtk_box_pack_start (GTK_BOX (vbox1), appGUI->cnt->import_vbox, FALSE, FALSE, 0);
 
@@ -299,36 +286,32 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_box_pack_start (GTK_BOX (appGUI->cnt->import_vbox), frame, TRUE, TRUE, 0);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_widget_show (alignment);
-    gtk_container_add (GTK_CONTAINER (frame), alignment);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
-    vbox4 = gtk_vbox_new (FALSE, 0);
+    vbox4 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_widget_show (vbox4);
-    gtk_container_add (GTK_CONTAINER (alignment), vbox4);
+    gtk_widget_set_margin_left(vbox4, 12);
+    gtk_container_add (GTK_CONTAINER (frame), vbox4);
 
-    hbox6 = gtk_hbox_new (FALSE, 8);
+    hbox6 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
     gtk_widget_show (hbox6);
     gtk_box_pack_start (GTK_BOX (vbox4), hbox6, TRUE, TRUE, 2);
 
-    hseparator = gtk_hseparator_new ();
+    hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show (hseparator);
     gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 4);
 
-    hbuttonbox = gtk_hbutton_box_new ();
+    hbuttonbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show (hbuttonbox);
     gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, TRUE, 0);
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), 8);
 
-	cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
+	cancel_button = gtk_button_new_with_mnemonic (_("_Cancel"));
     gtk_widget_show (cancel_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
     g_signal_connect(cancel_button, "clicked", 
                      G_CALLBACK(button_import_sel_window_close_cb), appGUI);
 
-	appGUI->cnt->import_button = utl_gui_create_labeled_button (OSMO_STOCK_BUTTON_CONTACTS_IMPORT, OSMO_STOCK_BUTTON_CONTACTS_IMPORT, _("Import"));
+	appGUI->cnt->import_button = gtk_button_new_with_mnemonic (_("Import"));
     gtk_widget_show (appGUI->cnt->import_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->cnt->import_button);
     g_signal_connect(appGUI->cnt->import_button, "clicked",
@@ -351,7 +334,7 @@ import_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 
     gtk_window_get_size (GTK_WINDOW(appGUI->cnt->import_window),
                         &config.contacts_import_win_w, &config.contacts_import_win_h);
-    gdk_window_get_root_origin (GDK_WINDOW(appGUI->cnt->import_window->window),
+    gdk_window_get_root_origin (gtk_widget_get_window(appGUI->cnt->import_window),
                                 &config.contacts_import_win_x, &config.contacts_import_win_y);
 
     gtk_widget_destroy(appGUI->cnt->import_window);
@@ -382,7 +365,7 @@ import_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
     GUI *appGUI = (GUI *)data;
 
     switch(event->keyval) {
-        case GDK_Escape:
+        case GDK_KEY_Escape:
             import_window_close_cb (widget, NULL, appGUI);
             return TRUE;
     }
@@ -556,7 +539,7 @@ gchar tmpbuf[BUFFER_SIZE];
         g_free(str);
     }
 
-    sprintf (tmpbuf, "%d %s.\n", n_records-n, ngettext ("contact added", "contacts added", n_records-n));
+    g_snprintf(tmpbuf, BUFFER_SIZE, "%d %s.\n", n_records-n, ngettext ("contact added", "contacts added", n_records-n));
     utl_gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW (appGUI->cnt->import_window));
     import_window_close_cb (NULL, NULL, appGUI);
 }
@@ -581,9 +564,9 @@ gchar tmpbuf[BUFFER_SIZE];
         }
     } 
 
-    GTK_ADJUSTMENT(appGUI->cnt->current_record_spinbutton_adj)->upper = n_records;
+    gtk_adjustment_set_upper(appGUI->cnt->current_record_spinbutton_adj, n_records);
     gtk_adjustment_set_value (GTK_ADJUSTMENT(appGUI->cnt->current_record_spinbutton_adj), 1.0);
-    sprintf(tmpbuf, "%d", n_records);
+    g_snprintf(tmpbuf, BUFFER_SIZE, "%d", n_records);
     gtk_label_set_text (GTK_LABEL(appGUI->cnt->n_records_label), tmpbuf);
 
     record_changed_cb (GTK_SPIN_BUTTON (appGUI->cnt->current_record_spinbutton), appGUI);
@@ -705,30 +688,32 @@ gchar tmpbuf[BUFFER_SIZE];
                 g_signal_connect (G_OBJECT (appGUI->cnt->import_window), "delete_event", 
                                   G_CALLBACK(import_window_close_cb), appGUI);
 
-                vbox1 = gtk_vbox_new (FALSE, 0);
+                vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
                 gtk_widget_show (vbox1);
                 gtk_container_add (GTK_CONTAINER (appGUI->cnt->import_window), vbox1);
 
-                vbox2 = gtk_vbox_new (FALSE, 0);
+                vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
                 gtk_widget_show (vbox2);
                 gtk_box_pack_start (GTK_BOX (vbox1), vbox2, TRUE, TRUE, 0);
 
-                hbox1 = gtk_hbox_new (FALSE, 0);
+                hbox1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
                 gtk_widget_show (hbox1);
                 gtk_box_pack_start (GTK_BOX (vbox2), hbox1, FALSE, TRUE, 4);
 
-                sprintf(tmpbuf, "%d", n_records);
+                g_snprintf(tmpbuf, BUFFER_SIZE, "%d", n_records);
                 appGUI->cnt->n_records_label = gtk_label_new (tmpbuf);
                 gtk_widget_show (appGUI->cnt->n_records_label);
                 gtk_box_pack_end (GTK_BOX (hbox1), appGUI->cnt->n_records_label, FALSE, FALSE, 0);
-                gtk_misc_set_padding (GTK_MISC (appGUI->cnt->n_records_label), 6, 0);
+                gtk_widget_set_margin_left (appGUI->cnt->n_records_label, 6);
+                gtk_widget_set_margin_right (appGUI->cnt->n_records_label, 6);
 
-                sprintf(tmpbuf, "<b>%s</b>", _("of"));
+                g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s</b>", _("of"));
                 label = gtk_label_new (tmpbuf);
                 gtk_widget_show (label);
                 gtk_box_pack_end (GTK_BOX (hbox1), label, FALSE, FALSE, 0);
                 gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-                gtk_misc_set_padding (GTK_MISC (label), 6, 0);
+                gtk_widget_set_margin_left (label, 6);
+                gtk_widget_set_margin_right (label, 6);
 
                 appGUI->cnt->current_record_spinbutton_adj = gtk_adjustment_new (1, 1, n_records, 1, 10, 0);
                 appGUI->cnt->current_record_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (appGUI->cnt->current_record_spinbutton_adj), 1, 0);
@@ -737,27 +722,30 @@ gchar tmpbuf[BUFFER_SIZE];
                                   G_CALLBACK(record_changed_cb), appGUI);
                 gtk_box_pack_end (GTK_BOX (hbox1), appGUI->cnt->current_record_spinbutton, FALSE, FALSE, 0);
 
-                sprintf(tmpbuf, "<b>%s:</b>", _("Record"));
+                g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Record"));
                 label = gtk_label_new (tmpbuf);
                 gtk_widget_show (label);
                 gtk_box_pack_end (GTK_BOX (hbox1), label, FALSE, FALSE, 0);
                 gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-                gtk_misc_set_padding (GTK_MISC (label), 6, 0);
+                gtk_widget_set_margin_left (label, 6);
+                gtk_widget_set_margin_right (label, 6);
 
-                sprintf(tmpbuf, "<b>%s:</b>", _("Number fields per record"));
+                g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Number fields per record"));
                 label = gtk_label_new (tmpbuf);
                 gtk_widget_show (label);
                 gtk_box_pack_start (GTK_BOX (hbox1), label, FALSE, FALSE, 0);
                 gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-                gtk_misc_set_padding (GTK_MISC (label), 6, 0);
+                gtk_widget_set_margin_left (label, 6);
+                gtk_widget_set_margin_right (label, 6);
 
-                sprintf(tmpbuf, "%d", appGUI->cnt->max_fields);
+                g_snprintf(tmpbuf, BUFFER_SIZE, "%d", appGUI->cnt->max_fields);
                 max_fields_label = gtk_label_new (tmpbuf);
                 gtk_widget_show (max_fields_label);
                 gtk_box_pack_start (GTK_BOX (hbox1), max_fields_label, FALSE, FALSE, 0);
-                gtk_misc_set_padding (GTK_MISC (max_fields_label), 6, 0);
+                gtk_widget_set_margin_left (max_fields_label, 6);
+                gtk_widget_set_margin_right (max_fields_label, 6);
 
-                hseparator = gtk_hseparator_new ();
+                hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
                 gtk_widget_show (hseparator);
                 gtk_box_pack_start (GTK_BOX (vbox2), hseparator, FALSE, TRUE, 8);
 
@@ -766,41 +754,41 @@ gchar tmpbuf[BUFFER_SIZE];
                 gtk_box_pack_start (GTK_BOX (vbox2), fields_scrolledwindow, TRUE, TRUE, 0);
                 gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (fields_scrolledwindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 
-                fields_table = gtk_table_new (appGUI->cnt->max_fields, 4, FALSE);
+                fields_table = gtk_grid_new ();
                 gtk_widget_show (fields_table);
                 gtk_container_set_border_width (GTK_CONTAINER (fields_table), 4);
-                gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW (fields_scrolledwindow), fields_table);
-                gtk_table_set_row_spacings (GTK_TABLE (fields_table), 4);
-                gtk_table_set_col_spacings (GTK_TABLE (fields_table), 4);
+                gtk_container_add(GTK_CONTAINER(fields_scrolledwindow), fields_table);
+                gtk_grid_set_row_spacing (GTK_GRID (fields_table), 4);
+                gtk_grid_set_column_spacing (GTK_GRID (fields_table), 4);
 
-                sprintf(tmpbuf, "%s", _("Use first record as header"));
+                g_snprintf(tmpbuf, BUFFER_SIZE, "%s", _("Use first record as header"));
                 appGUI->cnt->first_row_as_header_check_button = gtk_check_button_new_with_mnemonic (tmpbuf);
                 gtk_widget_show (appGUI->cnt->first_row_as_header_check_button);
                 gtk_box_pack_start (GTK_BOX (vbox1), appGUI->cnt->first_row_as_header_check_button, FALSE, TRUE, 4);
-                GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->first_row_as_header_check_button, GTK_CAN_FOCUS);
+                gtk_widget_set_can_focus(appGUI->cnt->first_row_as_header_check_button, FALSE);
                 g_signal_connect (G_OBJECT (appGUI->cnt->first_row_as_header_check_button), "toggled",
                                   G_CALLBACK (first_row_as_header_cb), appGUI);
 
-                hseparator = gtk_hseparator_new ();
+                hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
                 gtk_widget_show (hseparator);
                 gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 4);
 
-                hbuttonbox = gtk_hbutton_box_new ();
+                hbuttonbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
                 gtk_widget_show (hbuttonbox);
                 gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, TRUE, 0);
                 gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
                 gtk_box_set_spacing (GTK_BOX (hbuttonbox), 8);
 
-                cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
+                cancel_button = gtk_button_new_with_mnemonic (_("_Cancel"));
                 gtk_widget_show (cancel_button);
                 gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
-                GTK_WIDGET_SET_FLAGS (cancel_button, GTK_CAN_DEFAULT);
+                gtk_widget_set_can_default (cancel_button, TRUE);
                 g_signal_connect(cancel_button, "clicked", G_CALLBACK(button_import_window_close_cb), appGUI);
 
-                import_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CONTACTS_IMPORT);
+                import_button = gtk_button_new_with_mnemonic (_("Import"));
                 gtk_widget_show (import_button);
                 gtk_container_add (GTK_CONTAINER (hbuttonbox), import_button);
-                GTK_WIDGET_SET_FLAGS (import_button, GTK_CAN_DEFAULT);
+                gtk_widget_set_can_default (import_button, TRUE);
                 g_signal_connect(import_button, "clicked", G_CALLBACK(start_import_cb), appGUI);
 
                 gtk_widget_show(appGUI->cnt->import_window);
@@ -817,46 +805,46 @@ gchar tmpbuf[BUFFER_SIZE];
 
                 for(i=0; i < appGUI->cnt->max_fields; i++) {
 
-                    sprintf(tmpbuf, "<b>%s:</b>", _("Field type"));
+                    g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Field type"));
                     label = gtk_label_new (tmpbuf);
                     gtk_widget_show (label);
-                    gtk_table_attach (GTK_TABLE (fields_table), label, 0, 1, i, i+1,
-                                      (GtkAttachOptions) (GTK_FILL),
-                                      (GtkAttachOptions) (0), 0, 0);
+                    gtk_grid_attach (GTK_GRID (fields_table), label, 0, i, 1, 1);
                     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-                    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-                    gtk_misc_set_padding (GTK_MISC (label), 8, 0);
+                    gtk_widget_set_valign(label, GTK_ALIGN_START);
+                    gtk_widget_set_halign(label, GTK_ALIGN_CENTER);
+                    gtk_widget_set_margin_left (label, 8);
+                    gtk_widget_set_margin_right (label, 8);
 
-                    sprintf(tmpbuf, "<b>%s:</b>", _("Value"));
+                    g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Value"));
                     label = gtk_label_new (tmpbuf);
                     gtk_widget_show (label);
-                    gtk_table_attach (GTK_TABLE (fields_table), label, 2, 3, i, i+1,
-                                      (GtkAttachOptions) (GTK_FILL),
-                                      (GtkAttachOptions) (0), 0, 0);
+                    gtk_grid_attach (GTK_GRID (fields_table), label, 2, i, 1, 1);
                     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-                    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-                    gtk_misc_set_padding (GTK_MISC (label), 8, 0);
+                    gtk_widget_set_valign(label, GTK_ALIGN_START);
+                    gtk_widget_set_halign(label, GTK_ALIGN_CENTER);
+                    gtk_widget_set_margin_left (label, 8);
+                    gtk_widget_set_margin_right (label, 8);
 
                     appGUI->cnt->value_labels[i] = gtk_label_new ("");
                     gtk_widget_show (appGUI->cnt->value_labels[i]);
-                    gtk_table_attach (GTK_TABLE (fields_table), appGUI->cnt->value_labels[i], 3, 4, i, i+1,
-                                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                                      (GtkAttachOptions) (0), 0, 0);
+                    gtk_widget_set_hexpand(appGUI->cnt->value_labels[i], TRUE);
+                    gtk_grid_attach (GTK_GRID (fields_table), appGUI->cnt->value_labels[i], 3, i, 1, 1);
                     gtk_widget_set_size_request (appGUI->cnt->value_labels[i], 50, -1);
-                    gtk_misc_set_alignment (GTK_MISC (appGUI->cnt->value_labels[i]), 0, 0.5);
-                    gtk_misc_set_padding (GTK_MISC (appGUI->cnt->value_labels[i]), 8, 0);
+                    gtk_widget_set_valign(appGUI->cnt->value_labels[i], GTK_ALIGN_START);
+                    gtk_widget_set_halign(appGUI->cnt->value_labels[i], GTK_ALIGN_CENTER);
+                    gtk_widget_set_margin_left (appGUI->cnt->value_labels[i], 8);
+                    gtk_widget_set_margin_right (appGUI->cnt->value_labels[i], 8);
 
-                    appGUI->cnt->field_type_comboboxes[i] = gtk_combo_box_new_text ();
+                    appGUI->cnt->field_type_comboboxes[i] = gtk_combo_box_text_new ();
                     gtk_widget_show (appGUI->cnt->field_type_comboboxes[i]);
-                    gtk_table_attach (GTK_TABLE (fields_table), appGUI->cnt->field_type_comboboxes[i], 1, 2, i, i+1,
-                                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                                      (GtkAttachOptions) (0), 0, 0);
+                    gtk_widget_set_hexpand(appGUI->cnt->field_type_comboboxes[i], TRUE);
+                    gtk_grid_attach (GTK_GRID (fields_table), appGUI->cnt->field_type_comboboxes[i], 1, i, 1, 1);
                     gtk_container_set_border_width (GTK_CONTAINER (appGUI->cnt->field_type_comboboxes[i]), 4);
-                    sprintf(tmpbuf, "[%s]", _("None"));
-                    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->cnt->field_type_comboboxes[i]), tmpbuf);
+                    g_snprintf(tmpbuf, BUFFER_SIZE, "[%s]", _("None"));
+                    gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (appGUI->cnt->field_type_comboboxes[i]), NULL, tmpbuf);
 
                     for(j = 0; j < CONTACTS_NUM_COLUMNS; j++) {
-                        gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->cnt->field_type_comboboxes[i]), 
+                        gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (appGUI->cnt->field_type_comboboxes[i]), NULL,
                                                    gettext(appGUI->cnt->contact_fields_tags_name[j*2]));
                     }
 
