@@ -324,11 +324,11 @@ guint32 julian_day;
 
     julian_day = utl_date_dmy_to_julian (day, month + 1, year);
 
-    if (msg->data == (gpointer)COLUMN_BIRTH_DAY_DATE) {
+    if (GPOINTER_TO_INT(msg->data) == COLUMN_BIRTH_DAY_DATE) {
         temp = julian_to_str (julian_day, DATE_FULL, config.override_locale_settings);
         gtk_entry_set_text (GTK_ENTRY(msg->appGUI->cnt->contact_entries[COLUMN_BIRTH_DAY_DATE]), temp);
         msg->appGUI->cnt->birthday_date = julian_day;
-    } else if (msg->data == (gpointer)COLUMN_NAME_DAY_DATE) {
+    } else if (GPOINTER_TO_INT(msg->data) == COLUMN_NAME_DAY_DATE) {
         temp = julian_to_str (julian_day, DATE_NAME_DAY, config.override_locale_settings);
         gtk_entry_set_text (GTK_ENTRY(msg->appGUI->cnt->contact_entries[COLUMN_NAME_DAY_DATE]), temp);
         msg->appGUI->cnt->nameday_date = julian_day;
@@ -354,10 +354,10 @@ select_date_nodate_cb (GuiCalendar *s_calendar, gpointer user_data) {
 
     gtk_widget_destroy(msg->appGUI->cnt->select_date_window);
 
-    if (msg->data == (gpointer)COLUMN_BIRTH_DAY_DATE) {
+    if (GPOINTER_TO_INT(msg->data) == COLUMN_BIRTH_DAY_DATE) {
         gtk_entry_set_text (GTK_ENTRY(msg->appGUI->cnt->contact_entries[COLUMN_BIRTH_DAY_DATE]), "");
         msg->appGUI->cnt->birthday_date = 0;
-    } else if (msg->data == (gpointer)COLUMN_NAME_DAY_DATE) {
+    } else if (GPOINTER_TO_INT(msg->data) == COLUMN_NAME_DAY_DATE) {
         gtk_entry_set_text (GTK_ENTRY(msg->appGUI->cnt->contact_entries[COLUMN_NAME_DAY_DATE]), "");
         msg->appGUI->cnt->nameday_date = 0;
     }
@@ -468,16 +468,21 @@ static MESSAGE msg_selected;
 
     gtk_widget_show (msg->appGUI->cnt->select_date_window);
 
-    if (msg->data == (gpointer)COLUMN_BIRTH_DAY_DATE) {
+    if (GPOINTER_TO_INT(msg->data) == COLUMN_BIRTH_DAY_DATE) {
         if (g_date_valid_julian(msg->appGUI->cnt->birthday_date)) {
-            cdate = g_date_new_julian (msg->appGUI->cnt->birthday_date);
-            if (cdate != NULL) {
-                gui_calendar_select_month(GUI_CALENDAR(msg->appGUI->cnt->select_date_calendar), 
-                                          g_date_get_month(cdate)-1, g_date_get_year(cdate));
-                gui_calendar_select_day(GUI_CALENDAR(msg->appGUI->cnt->select_date_calendar), 
-                                        g_date_get_day(cdate));
-            }
+            cdate = g_date_new_julian(msg->appGUI->cnt->birthday_date);
         }
+    } else if (GPOINTER_TO_INT(msg->data) == COLUMN_NAME_DAY_DATE) {
+        if (g_date_valid_julian(msg->appGUI->cnt->nameday_date)) {
+            cdate = g_date_new_julian(msg->appGUI->cnt->nameday_date);
+        }
+    }
+    if (cdate != NULL) {
+        gui_calendar_select_month(GUI_CALENDAR(msg->appGUI->cnt->select_date_calendar),
+                g_date_get_month(cdate) - 1, g_date_get_year(cdate));
+        gui_calendar_select_day(GUI_CALENDAR(msg->appGUI->cnt->select_date_calendar),
+                g_date_get_day(cdate));
+        g_date_free(cdate);
     }
 }
 
@@ -702,7 +707,7 @@ gchar *contact_replace_tags[] = {
     appGUI->cnt->birth_day_date_button = gtk_button_new_from_icon_name (OSMO_STOCK_BUTTON_SELECT_DATE, GTK_ICON_SIZE_BUTTON);
     gtk_widget_set_can_focus(appGUI->cnt->birth_day_date_button, FALSE);
     gtk_widget_show (appGUI->cnt->birth_day_date_button);
-    msg_date[0].data = (gpointer)COLUMN_BIRTH_DAY_DATE;
+    msg_date[0].data = GINT_TO_POINTER(COLUMN_BIRTH_DAY_DATE);
     msg_date[0].appGUI = appGUI;
     g_signal_connect (G_OBJECT (appGUI->cnt->birth_day_date_button), "clicked",
                       G_CALLBACK (date_select_cb), &msg_date[0]);
@@ -730,7 +735,7 @@ gchar *contact_replace_tags[] = {
     appGUI->cnt->name_day_date_button = gtk_button_new_from_icon_name (OSMO_STOCK_BUTTON_SELECT_DATE, GTK_ICON_SIZE_BUTTON);
     gtk_widget_set_can_focus(appGUI->cnt->name_day_date_button, FALSE);
     gtk_widget_show (appGUI->cnt->name_day_date_button);
-    msg_date[1].data = (gpointer)COLUMN_NAME_DAY_DATE;
+    msg_date[1].data = GINT_TO_POINTER(COLUMN_NAME_DAY_DATE);
     msg_date[1].appGUI = appGUI;
     g_signal_connect (G_OBJECT (appGUI->cnt->name_day_date_button), "clicked",
                       G_CALLBACK (date_select_cb), &msg_date[1]);
@@ -1292,7 +1297,7 @@ gchar tmpbuf[BUFFER_SIZE];
         }
     }
 
-    xmlSaveFormatFileEnc (prefs_get_data_filename(CONTACTS_ENTRIES_FILENAME, appGUI), doc, "utf-8", 1);
+    utl_xml_write_doc (prefs_get_data_filename(CONTACTS_ENTRIES_FILENAME, appGUI), doc);
     xmlFreeProp (attr);
     xmlFreeDoc (doc);
 
