@@ -52,13 +52,12 @@ contacts_photo_size_changed_cb (GtkComboBox *widget, GUI *appGUI)
 /* ========================================================================== */
 
 static void
-contact_link_color_changed_cb (GtkColorButton *widget, GUI *appGUI)
+contact_link_color_changed_cb (GtkColorChooser *widget, GUI *appGUI)
 {
-	GdkColor color;
+	GdkRGBA color;
 
-	gtk_color_button_get_color (widget, &color);
-	g_snprintf (config.contact_link_color, MAXCOLORNAME, "#%02X%02X%02X",
-	            color.red * 256 / 65536, color.green * 256 / 65536, color.blue * 256 / 65536);
+	gtk_color_chooser_get_rgba (widget, &color);
+        utl_gui_convert_color_to_string(&color, config.contact_link_color);
 	g_object_set (G_OBJECT (appGUI->gui_url_tag), "foreground-gdk", &color, NULL);
 	g_signal_emit_by_name (G_OBJECT (appGUI->cnt->contacts_list_selection), "changed");
 }
@@ -66,13 +65,12 @@ contact_link_color_changed_cb (GtkColorButton *widget, GUI *appGUI)
 /* ========================================================================== */
 
 static void
-contact_tag_color_changed_cb (GtkColorButton *widget, GUI *appGUI)
+contact_tag_color_changed_cb (GtkColorChooser *widget, GUI *appGUI)
 {
-	GdkColor color;
+	GdkRGBA color;
 
-	gtk_color_button_get_color (widget, &color);
-	g_snprintf (config.contact_tag_color, MAXCOLORNAME, "#%02X%02X%02X",
-	            color.red * 256 / 65536, color.green * 256 / 65536, color.blue * 256 / 65536);
+	gtk_color_chooser_get_rgba (widget, &color);
+	utl_gui_convert_color_to_string (&color, config.contact_tag_color);
 	g_signal_emit_by_name (appGUI->cnt->contacts_list_selection, "changed");
 }
 
@@ -90,7 +88,7 @@ ci_font_size_changed_cb (GtkSpinButton *spinbutton, GUI *appGUI)
 {
 	config.contact_item_font_size = (gint) gtk_spin_button_get_value (spinbutton);
 #ifdef HAVE_LIBWEBKIT
-	g_object_set (appGUI->cnt->webkit_settings, "default-font-size", config.contact_item_font_size, NULL);
+        webkit_settings_set_default_font_size (webkit_web_view_get_settings(appGUI->cnt->html_webkitview), config.contact_item_font_size);
 #endif  /* LIBWEBKIT */
 	g_signal_emit_by_name (G_OBJECT (appGUI->cnt->contacts_list_selection), "changed");
 }
@@ -102,28 +100,26 @@ create_appearance_section (GtkWidget *appearance_vbox, GUI *appGUI)
 {
 	GtkWidget *table, *colors_hbox, *fonts_hbox, *photo_hbox, *spinbutton;
 	GtkWidget *label, *color_button, *combobox;
-	GtkObject *adjustment;
-	GdkColor color;
+	GtkAdjustment *adjustment;
+	GdkRGBA color;
 	gint i = 0;
 
-	table = gtk_table_new (5, 5, FALSE);
+	table = gtk_grid_new ();
 	gtk_box_pack_start (GTK_BOX (appearance_vbox), table, FALSE, FALSE, 0);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 4);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 8);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 4);
+	gtk_grid_set_row_spacing (GTK_GRID (table), 8);
 
 	label = utl_gui_create_label ("%s:", _("Colors"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), label, 0, i, 1, 1);
 
-	colors_hbox = gtk_hbox_new (FALSE, 8);
-	gtk_table_attach (GTK_TABLE (table), colors_hbox, 1, 4, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
+	colors_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
+	gtk_grid_attach (GTK_GRID (table), colors_hbox, 1, i, 3, 1);
 
 	color_button = gtk_color_button_new ();
 	if (config.enable_tooltips)
 		gtk_widget_set_tooltip_text (color_button, _("Color of contact tags"));
-	gdk_color_parse (config.contact_tag_color, &color);
-	gtk_color_button_set_color (GTK_COLOR_BUTTON (color_button), &color);
+	gdk_rgba_parse (&color, config.contact_tag_color);
+	gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (color_button), &color);
 	gtk_box_pack_start (GTK_BOX (colors_hbox), color_button, FALSE, FALSE, 0);
 	g_signal_connect (G_OBJECT (color_button), "color-set", G_CALLBACK (contact_tag_color_changed_cb), appGUI);
 	appGUI->opt->contact_tag_color_picker = color_button;
@@ -131,20 +127,18 @@ create_appearance_section (GtkWidget *appearance_vbox, GUI *appGUI)
 	color_button = gtk_color_button_new ();
 	if (config.enable_tooltips)
 		gtk_widget_set_tooltip_text (color_button, _("Color of links"));
-	gdk_color_parse (config.contact_link_color, &color);
-	gtk_color_button_set_color (GTK_COLOR_BUTTON (color_button), &color);
+	gdk_rgba_parse (&color, config.contact_link_color);
+	gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (color_button), &color);
 	gtk_box_pack_start (GTK_BOX (colors_hbox), color_button, FALSE, FALSE, 0);
 	g_signal_connect (G_OBJECT (color_button), "color-set", G_CALLBACK (contact_link_color_changed_cb), appGUI);
 	appGUI->opt->contact_link_color_picker = color_button;
 
 	i++;
 	label = utl_gui_create_label ("%s:", _("Font size"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), label, 0, i, 1, 1);
 
-	fonts_hbox = gtk_hbox_new (FALSE, 8);
-	gtk_table_attach (GTK_TABLE (table), fonts_hbox, 1, 4, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
+	fonts_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
+	gtk_grid_attach (GTK_GRID (table), fonts_hbox, 1, i, 3, 1);
 
 	adjustment = gtk_adjustment_new (0, 8, 48, 1, 10, 0);
 	spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 1, 0);
@@ -168,18 +162,16 @@ create_appearance_section (GtkWidget *appearance_vbox, GUI *appGUI)
 
 	i++;
 	label = utl_gui_create_label ("%s:", _("Photo size"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), label, 0, i, 1, 1);
 
-	photo_hbox = gtk_hbox_new (FALSE, 8);
-	gtk_table_attach (GTK_TABLE (table), photo_hbox, 1, 4, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
+	photo_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
+	gtk_grid_attach (GTK_GRID (table), photo_hbox, 1, i, 3, 1);
 
-	combobox = gtk_combo_box_new_text ();
+	combobox = gtk_combo_box_text_new ();
 	gtk_box_pack_start (GTK_BOX (photo_hbox), combobox, FALSE, FALSE, 0);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Small"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Medium"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Large"));
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("Small"));
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("Medium"));
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("Large"));
 	appGUI->opt->contacts_photo_size_combobox = combobox;
 	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (contacts_photo_size_changed_cb), appGUI);
 
@@ -226,17 +218,17 @@ create_miscellaneous_section (GtkWidget *miscellaneous_vbox, GUI *appGUI)
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (contacts_hide_group_column_changed_cb), appGUI);
 	appGUI->opt->contacts_hide_group_column_checkbutton = checkbutton;
 
-	maps_hbox = gtk_hbox_new (FALSE, 8);
+	maps_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_box_pack_start (GTK_BOX (miscellaneous_vbox), maps_hbox, TRUE, TRUE, 4);
 
     label = utl_gui_create_label ("%s:", _("Maps provider"));
 	gtk_box_pack_start (GTK_BOX (maps_hbox), label, FALSE, FALSE, 0);
 
-	combobox = gtk_combo_box_new_text ();
+	combobox = gtk_combo_box_text_new ();
 	gtk_box_pack_start (GTK_BOX (maps_hbox), combobox, FALSE, FALSE, 0);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "Google");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "Bing");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "OpenStreetMap");
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, "Google");
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, "Bing");
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, "OpenStreetMap");
 	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (maps_provider_changed_cb), appGUI);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), config.maps_provider);
 }
@@ -329,7 +321,7 @@ contacts_group_entry_key_release_cb (GtkEntry *widget, GdkEventKey *event, GUI *
 
 	gtk_widget_set_sensitive (appGUI->opt->contacts_group_add_button, state);
 
-	if (event->keyval == GDK_Return) {
+	if (event->keyval == GDK_KEY_Return) {
 		if (state) contacts_group_add_cb (NULL, appGUI);
 		return TRUE;
 	}
@@ -346,21 +338,22 @@ create_groups_section (GtkWidget *groups_vbox, GUI *appGUI)
 	GtkCellRenderer *renderer;
 	GtkWidget *table, *scrolledwindow, *treeview;
 
-	table = gtk_table_new (4, 3, FALSE);
+	table = gtk_grid_new ();
 	gtk_box_pack_start (GTK_BOX (groups_vbox), table, TRUE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (table), 8);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 8);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 4);
+	gtk_grid_set_row_spacing (GTK_GRID (table), 8);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 4);
 
 	appGUI->opt->contacts_group_entry = gtk_entry_new ();
-	gtk_table_attach (GTK_TABLE (table), appGUI->opt->contacts_group_entry, 0, 1, 3, 4,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_widget_set_hexpand(appGUI->opt->contacts_group_entry, TRUE);
+	gtk_grid_attach (GTK_GRID (table), appGUI->opt->contacts_group_entry, 0, 3, 1, 1);
 	g_signal_connect (G_OBJECT (appGUI->opt->contacts_group_entry), "key_release_event",
 	                  G_CALLBACK (contacts_group_entry_key_release_cb), appGUI);
 
 	scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
-	gtk_table_attach (GTK_TABLE (table), scrolledwindow, 0, 3, 0, 3,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
+	gtk_widget_set_hexpand(scrolledwindow, TRUE);
+	gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW (scrolledwindow), 80);
+	gtk_grid_attach (GTK_GRID (table), scrolledwindow, 0, 0, 3, 3);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_SHADOW_IN);
 
@@ -370,7 +363,6 @@ create_groups_section (GtkWidget *groups_vbox, GUI *appGUI)
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview), FALSE);
 	gtk_tree_view_set_reorderable (GTK_TREE_VIEW (treeview), TRUE);
 	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview), FALSE);
-	gtk_widget_set_size_request (treeview, -1, 80);
 	appGUI->opt->contacts_group_treeview = treeview;
 
 	appGUI->opt->contacts_group_select = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
@@ -383,16 +375,14 @@ create_groups_section (GtkWidget *groups_vbox, GUI *appGUI)
 	column = gtk_tree_view_column_new_with_attributes (NULL, renderer, "text", 0, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 
-	appGUI->opt->contacts_group_add_button = utl_gui_create_button (GTK_STOCK_ADD, OSMO_STOCK_BUTTON_ADD, FALSE);
+	appGUI->opt->contacts_group_add_button = gtk_button_new_from_icon_name ("list-add", GTK_ICON_SIZE_BUTTON);
 	gtk_widget_set_sensitive (appGUI->opt->contacts_group_add_button, FALSE);
-	gtk_table_attach (GTK_TABLE (table), appGUI->opt->contacts_group_add_button, 1, 2, 3, 4,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), appGUI->opt->contacts_group_add_button, 1, 3, 1, 1);
 	g_signal_connect (appGUI->opt->contacts_group_add_button, "clicked", G_CALLBACK (contacts_group_add_cb), appGUI);
 
-	appGUI->opt->contacts_group_remove_button = utl_gui_create_button (GTK_STOCK_REMOVE, OSMO_STOCK_BUTTON_REMOVE, FALSE);
+	appGUI->opt->contacts_group_remove_button = gtk_button_new_from_icon_name ("list-remove", GTK_ICON_SIZE_BUTTON);
 	gtk_widget_set_sensitive (appGUI->opt->contacts_group_remove_button, FALSE);
-	gtk_table_attach (GTK_TABLE (table), appGUI->opt->contacts_group_remove_button, 2, 3, 3, 4,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), appGUI->opt->contacts_group_remove_button, 2, 3, 1, 1);
 	g_signal_connect (appGUI->opt->contacts_group_remove_button, "clicked", G_CALLBACK (contacts_group_remove_cb), appGUI);
 }
 
@@ -403,29 +393,29 @@ create_visible_columns_section (GtkWidget *visible_columns_vbox, GUI *appGUI)
 {
 	GtkWidget *table, *checkbutton;
 
-	table = gtk_table_new (1, 3, FALSE);
+	table = gtk_grid_new ();
 	gtk_box_pack_start (GTK_BOX (visible_columns_vbox), table, FALSE, FALSE, 0);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 8);
+	gtk_grid_set_row_spacing (GTK_GRID (table), 4);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 8);
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Age"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.cnt_visible_age_column);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 0, 1, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(checkbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 0, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (checkbutton_clicked_cb), &(config.cnt_visible_age_column));
 	appGUI->opt->vc_age_checkbutton = checkbutton;
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Birthday date"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.cnt_visible_birthday_date_column);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 1, 2, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(checkbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 1, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (checkbutton_clicked_cb), &(config.cnt_visible_birthday_date_column));
 	appGUI->opt->vc_birthday_date_checkbutton = checkbutton;
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Zodiac sign"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.cnt_visible_zodiac_sign_column);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 2, 3, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(checkbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 2, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (checkbutton_clicked_cb), &(config.cnt_visible_zodiac_sign_column));
 	appGUI->opt->vc_zodiac_sign_checkbutton = checkbutton;
 }
@@ -437,7 +427,7 @@ cnt_create_preferences_page (GtkWidget *notebook, GUI *appGUI)
 {
 	GtkWidget *vbox_top, *vbox_icon, *vbox, *scrolledwindow;
 
-	vbox_top = gtk_vbox_new (FALSE, VBOX_SPACING);
+	vbox_top = gtk_box_new (GTK_ORIENTATION_VERTICAL, VBOX_SPACING);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox_top), BORDER_WIDTH);
 	scrolledwindow = utl_gui_insert_in_scrolled_window (vbox_top, GTK_SHADOW_ETCHED_IN);
 	gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow), 2);
