@@ -51,6 +51,9 @@
 #include "config.h"
 
 #include "gui_icon.h"
+#ifndef WIN32
+#include <glib-unix.h>
+#endif /* WIN32 */
 
 struct  osmo_prefs              config;
 /*------------------------------------------------------------------------------*/
@@ -1453,76 +1456,24 @@ GtkWidget   *systray_menu_separator;
 }
 
 /*------------------------------------------------------------------------------*/
-static int pipefd[2];
-
-static void
-pipe_signals(int signal)
-{
-  write(pipefd[1], &signal, sizeof(int));
-}
-
+#ifndef WIN32
 static gboolean
-deliver_signal(GIOChannel *source, GIOCondition cond, gpointer data)
+deliver_signal(gpointer data)
 {
     GUI *appGUI = data;
     gui_quit_osmo(appGUI);
-    return FALSE;
+    return G_SOURCE_CONTINUE;
 }
 
 static void
 register_signal_handler(GUI *appGUI) {
-    long fd_flags;
-    GIOChannel *g_signal_in;
-    GError *error = NULL;
-    struct sigaction sa;
-
-    if (pipe(pipefd)) {
-        return;
+    if(g_unix_signal_add(SIGINT, deliver_signal, appGUI) <= 0
+            || g_unix_signal_add(SIGTERM, deliver_signal, appGUI) <= 0
+            || g_unix_signal_add(SIGHUP, deliver_signal, appGUI) <= 0) {
+        g_warning("Failed to install the signal handler");
     }
-    fd_flags = fcntl(pipefd[1], F_GETFL);
-    if (fd_flags == -1) {
-        close(pipefd[0]);
-        close(pipefd[1]);
-        return;
-    }
-    if (fcntl(pipefd[1], F_SETFL, fd_flags | O_NONBLOCK) == -1) {
-        close(pipefd[0]);
-        close(pipefd[1]);
-        return;
-    }
-
-    sigemptyset(&sa.sa_mask);
-    sa.sa_handler = pipe_signals;
-    sa.sa_flags = 0;
-    if (sigaction(SIGINT, &sa, NULL)) {
-        close(pipefd[0]);
-        close(pipefd[1]);
-        return;
-    }
-    if (sigaction(SIGTERM, &sa, NULL)) {
-        close(pipefd[0]);
-        close(pipefd[1]);
-        return;
-    }
-
-    g_signal_in = g_io_channel_unix_new(pipefd[0]);
-    g_io_channel_set_encoding(g_signal_in, NULL, &error);
-    if (error != NULL) {
-        close(pipefd[0]);
-        close(pipefd[1]);
-        return;
-    }
-
-    g_io_channel_set_flags(g_signal_in, g_io_channel_get_flags(g_signal_in) | G_IO_FLAG_NONBLOCK, &error);
-
-    if (error != NULL) {
-        close(pipefd[0]);
-        close(pipefd[1]);
-        return;
-    }
-
-    g_io_add_watch(g_signal_in, G_IO_IN | G_IO_PRI, deliver_signal, appGUI);
 }
+#endif /* WIN32 */
 /*------------------------------------------------------------------------------*/
 
 gboolean
@@ -1665,9 +1616,9 @@ gui_create_window (GUI *appGUI)
             gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->nte->cf_combobox), 0);
         }
 #endif  /* NOTES_ENABLED */
-
+#ifndef WIN32
         register_signal_handler(appGUI);
-
+#endif /* WIN32 */
 #ifdef TASKS_ENABLED
         refresh_tasks (appGUI);
         appGUI->tsk->notifications_enable = TRUE;
