@@ -1299,7 +1299,7 @@ xmlChar *escaped;
 		g_free (note_filename);
 	}
 
-	xmlSaveFormatFileEnc (prefs_get_data_filename (NOTES_ENTRIES_FILENAME, appGUI), doc, "utf-8", 1);
+	utl_xml_write_doc (prefs_get_data_filename (NOTES_ENTRIES_FILENAME, appGUI), doc);
 	xmlFreeProp (attr);
 	xmlFreeDoc (doc);
 
