@@ -86,14 +86,6 @@ get_comp_ratio_value (void)
 
 /* ========================================================================== */
 
-static void
-combobox_clicked_cb (GtkComboBox *combobox, gint *option)
-{
-	*option = gtk_combo_box_get_active (combobox);
-}
-
-/* ========================================================================== */
-
 static void
 checkbutton_clicked_cb (GtkToggleButton *togglebutton, gint *option)
 {
@@ -101,6 +93,7 @@ checkbutton_clicked_cb (GtkToggleButton *togglebutton, gint *option)
 }
 
 /* ========================================================================== */
+#ifdef HAVE_LIBGRINGOTTS
 
 static void
 notes_comp_ratio_cb (GtkComboBox *combobox, gint *option)
@@ -110,73 +103,78 @@ notes_comp_ratio_cb (GtkComboBox *combobox, gint *option)
 
 /* ========================================================================== */
 
-#ifdef HAVE_LIBGRINGOTTS
+static void
+combobox_clicked_cb (GtkComboBox *combobox, gint *option)
+{
+	*option = gtk_combo_box_get_active (combobox);
+}
+/* ========================================================================== */
 
 static void
 create_encryption_section (GtkWidget *encryption_vbox, GUI *appGUI)
 {
 	GtkWidget *table, *combobox, *label;
 
-	table = gtk_table_new (1, 5, FALSE);
+	table = gtk_grid_new ();
 	gtk_box_pack_start (GTK_BOX (encryption_vbox), table, FALSE, FALSE, 0);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 8);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 8);
+	gtk_grid_set_row_spacing (GTK_GRID (table), 8);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 8);
 
 	label = utl_gui_create_label ("%s:", _("Algorithm"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(label, TRUE);
+	gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
 
 	label = utl_gui_create_label ("%s:", _("Hashing"));
-	gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(label, TRUE);
+	gtk_grid_attach (GTK_GRID (table), label, 2, 0, 1, 1);
 
-	combobox = gtk_combo_box_new_text ();
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "AES");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "Serpent");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "Twofish");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "CAST 256");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "Safer+");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "Loki 97");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "Triple DES");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "Rijndael");
+	combobox = gtk_combo_box_text_new ();
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, "AES");
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, "Serpent");
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, "Twofish");
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, "CAST 256");
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, "Safer+");
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, "Loki 97");
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, "Triple DES");
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, "Rijndael");
 	gtk_combo_box_set_active (GTK_COMBO_BOX(combobox), config.notes_enc_algorithm);
-	gtk_table_attach (GTK_TABLE (table), combobox, 1, 2, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(combobox, TRUE);
+	gtk_grid_attach (GTK_GRID (table), combobox, 1, 0, 1, 1);
 	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (combobox_clicked_cb), &(config.notes_enc_algorithm));
 	appGUI->opt->notes_enc_algorithm_combobox = combobox;
 
-	combobox = gtk_combo_box_new_text ();
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "SHA-1");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "RIPEMD-160");
+	combobox = gtk_combo_box_text_new ();
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, "SHA-1");
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, "RIPEMD-160");
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), config.notes_enc_hashing);
-	gtk_table_attach (GTK_TABLE (table), combobox, 3, 4, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(combobox, TRUE);
+	gtk_grid_attach (GTK_GRID (table), combobox, 3, 0, 1, 1);
 	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (combobox_clicked_cb), &(config.notes_enc_algorithm));
 	appGUI->opt->notes_enc_hashing_combobox = combobox;
 
 	label = utl_gui_create_label ("%s:", _("Compression"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(label, TRUE);
+	gtk_grid_attach (GTK_GRID (table), label, 0, 1, 1, 1);
 
 	label = utl_gui_create_label ("%s:", _("Ratio"));
-	gtk_table_attach (GTK_TABLE (table), label, 2, 3, 1, 2,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(label, TRUE);
+	gtk_grid_attach (GTK_GRID (table), label, 2, 1, 1, 1);
 
-	combobox = gtk_combo_box_new_text ();
-	gtk_table_attach (GTK_TABLE (table), combobox, 1, 2, 1, 2,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "ZLib");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "BZip2");
+	combobox = gtk_combo_box_text_new ();
+        gtk_widget_set_hexpand(combobox, TRUE);
+	gtk_grid_attach (GTK_GRID (table), combobox, 1, 1, 1, 1);
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, "ZLib");
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, "BZip2");
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), config.notes_comp_algorithm);
 	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (combobox_clicked_cb), &(config.notes_comp_algorithm));
 	appGUI->opt->notes_comp_algorithm_combobox = combobox;
 
-	combobox = gtk_combo_box_new_text ();
-	gtk_table_attach (GTK_TABLE (table), combobox, 3, 4, 1, 2,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Fast"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Good"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Best"));
+	combobox = gtk_combo_box_text_new ();
+        gtk_widget_set_hexpand(combobox, TRUE);
+	gtk_grid_attach (GTK_GRID (table), combobox, 3, 1, 1, 1);
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("Fast"));
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("Good"));
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("Best"));
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), config.notes_comp_ratio - 1);
 	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (notes_comp_ratio_cb), &(config.notes_comp_ratio));
 	appGUI->opt->notes_comp_ratio_combobox = combobox;
@@ -211,36 +209,36 @@ create_visible_columns_section (GtkWidget *visible_columns_vbox, GUI *appGUI)
 {
 	GtkWidget *table, *checkbutton;
 
-	table = gtk_table_new (1, 4, FALSE);
+	table = gtk_grid_new ();
 	gtk_box_pack_start (GTK_BOX (visible_columns_vbox), table, FALSE, FALSE, 0);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 8);
+	gtk_grid_set_row_spacing (GTK_GRID (table), 4);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 8);
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Type"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.nte_visible_type_column);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 0, 1, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(checkbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 0, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (notes_visible_columns_changed_cb), appGUI);
 	appGUI->opt->nvc_type_checkbutton = checkbutton;
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Category"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.nte_visible_category_column);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 1, 2, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(checkbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 1, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (notes_visible_columns_changed_cb), appGUI);
 	appGUI->opt->nvc_category_checkbutton = checkbutton;
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Last changes"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.nte_visible_last_changes_column);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 2, 3, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(checkbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 2, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (notes_visible_columns_changed_cb), appGUI);
 	appGUI->opt->nvc_last_changes_checkbutton = checkbutton;
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Created"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.nte_visible_created_column);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 3, 4, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(checkbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 3, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (notes_visible_columns_changed_cb), appGUI);
 	appGUI->opt->nvc_created_checkbutton = checkbutton;
 }
@@ -307,7 +305,7 @@ notes_category_entry_key_release_cb (GtkEntry *entry, GdkEventKey *event, GUI *a
 
 	gtk_widget_set_sensitive (appGUI->opt->notes_category_add_button, state);
 
-	if (event->keyval == GDK_Return) {
+	if (event->keyval == GDK_KEY_Return) {
 		if (state) notes_category_add_cb (NULL, appGUI);
 		return TRUE;
 	}
@@ -359,20 +357,22 @@ create_categories_section (GtkWidget *categories_vbox, GUI *appGUI)
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *renderer;
 
-	table = gtk_table_new (4, 3, FALSE);
+	table = gtk_grid_new ();
 	gtk_box_pack_start (GTK_BOX (categories_vbox), table, TRUE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (table), 8);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 8);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 4);
+	gtk_grid_set_row_spacing (GTK_GRID (table), 8);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 4);
 
 	entry = gtk_entry_new ();
-	gtk_table_attach (GTK_TABLE (table), entry, 0, 1, 3, 4,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(entry, TRUE);
+	gtk_grid_attach (GTK_GRID (table), entry, 0, 3, 1, 1);
 	g_signal_connect (G_OBJECT (entry), "key_release_event", G_CALLBACK (notes_category_entry_key_release_cb), appGUI);
 	appGUI->opt->notes_category_entry = entry;
 
 	scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
-	gtk_table_attach_defaults (GTK_TABLE (table), scrolledwindow, 0, 3, 0, 3);
+	gtk_widget_set_hexpand(scrolledwindow, TRUE);
+	gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW (scrolledwindow), 80);
+	gtk_grid_attach (GTK_GRID (table), scrolledwindow, 0, 0, 3, 3);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_SHADOW_IN);
 
@@ -383,7 +383,6 @@ create_categories_section (GtkWidget *categories_vbox, GUI *appGUI)
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview), FALSE);
 	gtk_tree_view_set_reorderable (GTK_TREE_VIEW (treeview), TRUE);
 	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview), FALSE);
-	gtk_widget_set_size_request (treeview, -1, 80);
 
 	appGUI->opt->notes_category_select = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
 	g_signal_connect (G_OBJECT (appGUI->opt->notes_category_select), "changed", G_CALLBACK (notes_category_selected_cb), appGUI);
@@ -395,15 +394,13 @@ create_categories_section (GtkWidget *categories_vbox, GUI *appGUI)
 	column = gtk_tree_view_column_new_with_attributes(NULL, renderer, "text", 0, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 
-	appGUI->opt->notes_category_add_button = utl_gui_create_button (GTK_STOCK_ADD, OSMO_STOCK_BUTTON_ADD, FALSE);
-	gtk_table_attach (GTK_TABLE (table), appGUI->opt->notes_category_add_button, 1, 2, 3, 4,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	appGUI->opt->notes_category_add_button = gtk_button_new_from_icon_name ("list-add", GTK_ICON_SIZE_BUTTON);
+	gtk_grid_attach (GTK_GRID (table), appGUI->opt->notes_category_add_button, 1, 3, 1, 1);
 	gtk_widget_set_sensitive (appGUI->opt->notes_category_add_button, FALSE);
 	g_signal_connect (appGUI->opt->notes_category_add_button, "clicked", G_CALLBACK (notes_category_add_cb), appGUI);
 
-	appGUI->opt->notes_category_remove_button = utl_gui_create_button (GTK_STOCK_REMOVE, OSMO_STOCK_BUTTON_REMOVE, FALSE);
-	gtk_table_attach (GTK_TABLE (table), appGUI->opt->notes_category_remove_button, 2, 3, 3, 4,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	appGUI->opt->notes_category_remove_button = gtk_button_new_from_icon_name ("list-remove", GTK_ICON_SIZE_BUTTON);
+	gtk_grid_attach (GTK_GRID (table), appGUI->opt->notes_category_remove_button, 2, 3, 1, 1);
 	gtk_widget_set_sensitive (appGUI->opt->notes_category_remove_button, FALSE);
 	g_signal_connect (appGUI->opt->notes_category_remove_button, "clicked", G_CALLBACK (notes_category_remove_cb), appGUI);
 }
@@ -435,7 +432,7 @@ nte_create_preferences_page (GtkWidget *notebook, GUI *appGUI)
 {
 	GtkWidget *vbox_top, *vbox_icon, *vbox, *scrolledwindow;
 
-	vbox_top = gtk_vbox_new (FALSE, VBOX_SPACING);
+	vbox_top = gtk_box_new (GTK_ORIENTATION_VERTICAL, VBOX_SPACING);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox_top), BORDER_WIDTH);
 	scrolledwindow = utl_gui_insert_in_scrolled_window (vbox_top, GTK_SHADOW_ETCHED_IN);
 	gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow), 2);
