@@ -347,10 +347,10 @@ override_locale_changed_cb (GtkToggleButton *togglebutton, GUI *appGUI)
 	gtk_widget_set_sensitive (appGUI->opt->date_format_combobox, config.override_locale_settings);
 	gtk_widget_set_sensitive (appGUI->opt->time_format_combobox, config.override_locale_settings);
 
-#ifdef HAVE_GTKSPELL
+#ifdef HAVE_GSPELL
 	gtk_widget_set_sensitive (appGUI->opt->override_locale_label_3, config.override_locale_settings);
 	gtk_widget_set_sensitive (appGUI->opt->entry_spell_lang, config.override_locale_settings);
-#endif  /* HAVE_GTKSPELL */
+#endif  /* HAVE_GSPELL */
 
 #ifdef TASKS_ENABLED
 	refresh_tasks (appGUI);
@@ -396,7 +396,7 @@ time_format_changed_cb (GtkComboBox *widget, GUI *appGUI)
 
 /* ========================================================================== */
 
-#ifdef HAVE_GTKSPELL
+#ifdef HAVE_GSPELL
 
 static void
 spell_checker_entry_changed_cb (GtkEntry *entry, GUI *appGUI)
@@ -416,7 +416,7 @@ spell_checker_key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
 	return FALSE;
 }
 
-#endif  /* HAVE_GTKSPELL */
+#endif  /* HAVE_GSPELL */
 
 /* ========================================================================== */
 
@@ -472,7 +472,7 @@ create_general_section (GtkWidget *general_vbox, GUI *appGUI)
 
 	i++;
 
-#ifdef HAVE_GTKSPELL
+#ifdef HAVE_GSPELL
 
 	GtkWidget *entry;
 
@@ -481,7 +481,7 @@ create_general_section (GtkWidget *general_vbox, GUI *appGUI)
 
 	entry = gtk_entry_new ();
 	gtk_entry_set_max_length (GTK_ENTRY (entry), MAXNAME);
-    gtk_entry_set_text (GTK_ENTRY (entry), config.spell_lang);
+        gtk_entry_set_text (GTK_ENTRY (entry), config.spell_lang);
 	gtk_grid_attach (GTK_GRID (table), entry, 1, i, 1, 1);
 	g_signal_connect (G_OBJECT (entry), "activate", G_CALLBACK (spell_checker_entry_changed_cb), appGUI);
 	g_signal_connect (G_OBJECT (entry), "key_press_event", G_CALLBACK (spell_checker_key_press_cb), appGUI);
@@ -489,7 +489,7 @@ create_general_section (GtkWidget *general_vbox, GUI *appGUI)
 
 	i++;
 
-#endif /* HAVE_GTKSPELL */
+#endif /* HAVE_GSPELL */
 	/* update the button enablement */
 	override_locale_changed_cb(GTK_TOGGLE_BUTTON (appGUI->opt->override_locale_checkbutton), appGUI);
 
