@@ -121,10 +121,9 @@
 
 #define     OSMO_STOCK_TYPE_NORMAL              "osmo-type-normal"
 #define     OSMO_STOCK_TYPE_ENCRYPTED           "osmo-type-encrypted"
-//#define     OSMO_STOCK_TYPE_RECURRENT_INACTIVE  "osmo-type-recurrent-inactive"
 #define     OSMO_STOCK_TYPE_RECURRENT           "osmo-type-recurrent"
 
-void    osmo_register_stock_icons   (void);
+void    osmo_register_theme_icons   ();
 
 #endif /* _STOCK_ICONS_H */
 
