@@ -27,11 +27,8 @@
 
 void            read_tasks_entries          (GUI *appGUI);
 void            write_tasks_entries         (GUI *appGUI);
-void            tasks_remove_dialog_show    (GtkWidget *list, GtkListStore *list_store, GUI *appGUI);
+void            tasks_remove_dialog_show    (GUI *appGUI);
 void            tasks_add_edit_dialog_show  (gboolean tasks_edit_mode, guint32 julian_date, gint time, GUI *appGUI);
-GtkTreeIter *   task_get_iter               (gint id, GUI *appGUI);
-TASK_ITEM *     get_task_item               (GtkTreeIter *iter, GUI *appGUI);
-void            task_item_free              (TASK_ITEM *item);
 
 #endif /* _TASKS_ITEMS_H */
 
