@@ -40,39 +40,36 @@ checkbutton_clicked_cb (GtkToggleButton *togglebutton, gint *option)
 /* ========================================================================== */
 
 static void
-due_today_color_changed_cb (GtkColorButton *color_button, GUI *appGUI)
+due_today_color_changed_cb (GtkColorChooser *color_button, GUI *appGUI)
 {
-	GdkColor color;
+	GdkRGBA color;
 
-	gtk_color_button_get_color (color_button, &color);
-	g_snprintf (config.due_today_color, MAXCOLORNAME, "#%02X%02X%02X",
-	            color.red * 256 / 65536, color.green * 256 / 65536, color.blue * 256 / 65536);
+	gtk_color_chooser_get_rgba (color_button, &color);
+	utl_gui_convert_color_to_string (&color, config.due_today_color);
 	refresh_tasks (appGUI);
 }
 
 /* ========================================================================== */
 
 static void
-due_7days_color_changed_cb (GtkColorButton *color_button, GUI *appGUI)
+due_7days_color_changed_cb (GtkColorChooser *color_button, GUI *appGUI)
 {
-	GdkColor color;
+	GdkRGBA color;
 
-	gtk_color_button_get_color (color_button, &color);
-	g_snprintf (config.due_7days_color, MAXCOLORNAME, "#%02X%02X%02X",
-	            color.red * 256 / 65536, color.green * 256 / 65536, color.blue * 256 / 65536);
+	gtk_color_chooser_get_rgba (color_button, &color);
+	utl_gui_convert_color_to_string(&color, config.due_7days_color);
 	refresh_tasks (appGUI);
 }
 
 /* ========================================================================== */
 
 static void
-past_due_color_changed_cb (GtkColorButton *color_button, GUI *appGUI)
+past_due_color_changed_cb (GtkColorChooser *color_button, GUI *appGUI)
 {
-	GdkColor color;
+	GdkRGBA color;
 
-	gtk_color_button_get_color (color_button, &color);
-	g_snprintf (config.past_due_color, MAXCOLORNAME, "#%02X%02X%02X",
-	            color.red * 256 / 65536, color.green * 256 / 65536, color.blue * 256 / 65536);
+	gtk_color_chooser_get_rgba (color_button, &color);
+	utl_gui_convert_color_to_string (&color, config.past_due_color);
 	refresh_tasks (appGUI);
 }
 
@@ -94,16 +91,16 @@ ti_font_select_cb (GtkWidget *widget, GUI *appGUI)
 	gchar *font_name;
 	gint response;
 
-	font_selector = gtk_font_selection_dialog_new (_("Select a font..."));
+	font_selector = gtk_font_chooser_dialog_new (_("Select a font..."), GTK_WINDOW (appGUI->main_window));
 	gtk_window_set_modal (GTK_WINDOW (font_selector), TRUE);
 	gtk_window_set_position (GTK_WINDOW (font_selector), GTK_WIN_POS_MOUSE);
 	gtk_window_set_transient_for (GTK_WINDOW (font_selector), GTK_WINDOW (appGUI->main_window));
-	gtk_font_selection_dialog_set_font_name (GTK_FONT_SELECTION_DIALOG (font_selector), config.task_info_font);
+	gtk_font_chooser_set_font (GTK_FONT_CHOOSER (font_selector), config.task_info_font);
 	gtk_widget_show (font_selector);
 	response = gtk_dialog_run (GTK_DIALOG (font_selector));
 
 	if (response == GTK_RESPONSE_OK) {
-		font_name = gtk_font_selection_dialog_get_font_name (GTK_FONT_SELECTION_DIALOG (font_selector));
+		font_name = gtk_font_chooser_get_font  (GTK_FONT_CHOOSER (font_selector));
 		g_strlcpy (config.task_info_font, font_name, MAXFONTNAME);
 		gtk_entry_set_text (GTK_ENTRY (appGUI->opt->ti_font_entry), font_name);
 		g_free (font_name);
@@ -120,22 +117,21 @@ create_appearance_section (GtkWidget *appearance_vbox, GUI *appGUI)
 {
 	GtkWidget *table, *colors_hbox;
 	GtkWidget *checkbutton, *label, *color_button, *font_button;
-	GdkColor color;
+	GdkRGBA color;
 
-	table = gtk_table_new (4, 4, FALSE);
+	table = gtk_grid_new ();
 	gtk_box_pack_start (GTK_BOX (appearance_vbox), table, FALSE, FALSE, 0);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 4);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 8);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 4);
+	gtk_grid_set_row_spacing (GTK_GRID (table), 8);
 
-	colors_hbox = gtk_hbox_new (FALSE, 8);
-	gtk_table_attach (GTK_TABLE (table), colors_hbox, 1, 2, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
+	colors_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
+	gtk_grid_attach (GTK_GRID (table), colors_hbox, 1, 0, 1, 1);
 
 	color_button = gtk_color_button_new ();
 	if (config.enable_tooltips)
 		gtk_widget_set_tooltip_text (color_button, _("Color of items that are due today"));
-	gdk_color_parse (config.due_today_color, &color);
-	gtk_color_button_set_color (GTK_COLOR_BUTTON (color_button), &color);
+	gdk_rgba_parse (&color, config.due_today_color);
+	gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (color_button), &color);
 	gtk_box_pack_start (GTK_BOX (colors_hbox), color_button, FALSE, FALSE, 0);
 	g_signal_connect (G_OBJECT (color_button), "color-set", G_CALLBACK (due_today_color_changed_cb), appGUI);
 	appGUI->opt->due_today_color_picker = color_button;
@@ -144,43 +140,39 @@ create_appearance_section (GtkWidget *appearance_vbox, GUI *appGUI)
 	g_signal_connect (G_OBJECT (color_button), "color-set", G_CALLBACK (due_7days_color_changed_cb), appGUI);
 	if (config.enable_tooltips)
 		gtk_widget_set_tooltip_text (color_button, _("Color of items that are due in the next 7 days"));
-	gdk_color_parse (config.due_7days_color, &color);
-	gtk_color_button_set_color (GTK_COLOR_BUTTON (color_button), &color);
+	gdk_rgba_parse (&color, config.due_7days_color);
+	gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (color_button), &color);
 	gtk_box_pack_start (GTK_BOX (colors_hbox), color_button, FALSE, FALSE, 0);
 	appGUI->opt->due_7days_color_picker = color_button;
 
 	color_button = gtk_color_button_new ();
 	if (config.enable_tooltips)
 		gtk_widget_set_tooltip_text (color_button, _("Color of items that are past due"));
-	gdk_color_parse(config.past_due_color, &color);
-	gtk_color_button_set_color (GTK_COLOR_BUTTON (color_button), &color);
+	gdk_rgba_parse(&color, config.past_due_color);
+	gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (color_button), &color);
 	gtk_box_pack_start (GTK_BOX (colors_hbox), color_button, FALSE, FALSE, 0);
 	g_signal_connect (G_OBJECT (color_button), "color-set", G_CALLBACK (past_due_color_changed_cb), appGUI);
 	appGUI->opt->past_due_color_picker = color_button;
 
 	appGUI->opt->ti_font_entry = gtk_entry_new ();
 	gtk_entry_set_text (GTK_ENTRY (appGUI->opt->ti_font_entry), config.task_info_font);
-	GTK_WIDGET_UNSET_FLAGS (appGUI->opt->ti_font_entry, GTK_CAN_FOCUS);
-	gtk_table_attach (GTK_TABLE (table), appGUI->opt->ti_font_entry, 1, 2, 1, 2,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_widget_set_can_focus (appGUI->opt->ti_font_entry, FALSE);
+        gtk_widget_set_hexpand(appGUI->opt->ti_font_entry, TRUE);
+	gtk_grid_attach (GTK_GRID (table), appGUI->opt->ti_font_entry, 1, 1, 1, 1);
 
-	font_button = utl_gui_create_button (GTK_STOCK_SELECT_FONT, OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
-	gtk_table_attach (GTK_TABLE (table), font_button, 2, 3, 1, 2,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	font_button = gtk_button_new_from_icon_name ("gtk-select-font", GTK_ICON_SIZE_BUTTON);
+	gtk_grid_attach (GTK_GRID (table), font_button, 2, 1, 1, 1);
 	g_signal_connect (G_OBJECT (font_button), "clicked", G_CALLBACK (ti_font_select_cb), appGUI);
 
 	label = utl_gui_create_label ("%s:", _("Task info font"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), label, 0, 1, 1, 1);
 
 	label = utl_gui_create_label ("%s:", _("Colors"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Show in bold tasks with high priority"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.tasks_high_in_bold);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 0, 3, 3, 4,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 0, 3, 3, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (bold_items_cb), appGUI);
 	appGUI->opt->ct_bold_items_checkbutton = checkbutton;
 }
@@ -209,36 +201,36 @@ create_visible_columns_section (GtkWidget *visible_columns_vbox, GUI *appGUI)
 {
 	GtkWidget *table, *checkbutton;
 
-	table = gtk_table_new (1, 4, FALSE);
+	table = gtk_grid_new ();
 	gtk_box_pack_start (GTK_BOX (visible_columns_vbox), table, FALSE, FALSE, 0);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 8);
+	gtk_grid_set_row_spacing (GTK_GRID (table), 4);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 8);
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Due date"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.tsk_visible_due_date_column);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 0, 1, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(checkbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 0, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (visible_columns_changed_cb), appGUI);
 	appGUI->opt->vc_due_date_checkbutton = checkbutton;
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Type"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.tsk_visible_type_column);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 1, 2, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(checkbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 1, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (visible_columns_changed_cb), appGUI);
 	appGUI->opt->vc_type_checkbutton = checkbutton;
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Priority"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.tsk_visible_priority_column);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 2, 3, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(checkbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 2, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (visible_columns_changed_cb), appGUI);
 	appGUI->opt->vc_priority_checkbutton = checkbutton;
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Category"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.tsk_visible_category_column);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 3, 4, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(checkbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 3, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (visible_columns_changed_cb), appGUI);
 	appGUI->opt->vc_category_checkbutton = checkbutton;
 }
@@ -391,7 +383,7 @@ tasks_category_entry_key_release_cb (GtkEntry *widget, GdkEventKey *event, GUI *
 
 	gtk_widget_set_sensitive (appGUI->opt->tasks_category_add_button, state);
 
-	if (event->keyval == GDK_Return) {
+	if (event->keyval == GDK_KEY_Return) {
 		if (state) tasks_category_add_cb (NULL, appGUI);
 		return TRUE;
 	}
@@ -408,21 +400,22 @@ create_categories_section (GtkWidget *categories_vbox, GUI *appGUI)
 	GtkCellRenderer *renderer;
 	GtkWidget *table, *scrolledwindow, *treeview;
 
-	table = gtk_table_new (4, 3, FALSE);
+	table = gtk_grid_new ();
 	gtk_box_pack_start (GTK_BOX (categories_vbox), table, TRUE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (table), 8);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 8);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 4);
+	gtk_grid_set_row_spacing (GTK_GRID (table), 8);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 4);
 
 	appGUI->opt->tasks_category_entry = gtk_entry_new ();
-	gtk_table_attach (GTK_TABLE (table), appGUI->opt->tasks_category_entry, 0, 1, 3, 4,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(appGUI->opt->tasks_category_entry, TRUE);
+	gtk_grid_attach (GTK_GRID (table), appGUI->opt->tasks_category_entry, 0, 3, 1, 1);
 	g_signal_connect (G_OBJECT (appGUI->opt->tasks_category_entry), "key_release_event",
 	                  G_CALLBACK (tasks_category_entry_key_release_cb), appGUI);
 
 	scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
-	gtk_table_attach (GTK_TABLE (table), scrolledwindow, 0, 3, 0, 3,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
+	gtk_widget_set_hexpand(scrolledwindow, TRUE);
+	gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW (scrolledwindow), 120);
+	gtk_grid_attach (GTK_GRID (table), scrolledwindow, 0, 0, 3, 3);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_SHADOW_IN);
 
@@ -432,7 +425,6 @@ create_categories_section (GtkWidget *categories_vbox, GUI *appGUI)
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview), TRUE);
 	gtk_tree_view_set_reorderable (GTK_TREE_VIEW (treeview), TRUE);
 	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview), FALSE);
-	gtk_widget_set_size_request (treeview, -1, 120);
 	appGUI->opt->tasks_category_treeview = treeview;
 
 	appGUI->opt->tasks_category_select = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
@@ -456,16 +448,14 @@ create_categories_section (GtkWidget *categories_vbox, GUI *appGUI)
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	g_signal_connect (renderer, "toggled", G_CALLBACK (tsk_show_in_tasks_list_toggled), appGUI);
 
-	appGUI->opt->tasks_category_add_button = utl_gui_create_button (GTK_STOCK_ADD, OSMO_STOCK_BUTTON_ADD, FALSE);
+	appGUI->opt->tasks_category_add_button = gtk_button_new_from_icon_name ("list-add", GTK_ICON_SIZE_BUTTON);
 	gtk_widget_set_sensitive (appGUI->opt->tasks_category_add_button, FALSE);
-	gtk_table_attach (GTK_TABLE (table), appGUI->opt->tasks_category_add_button, 1, 2, 3, 4,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), appGUI->opt->tasks_category_add_button, 1, 3, 1, 1);
 	g_signal_connect (appGUI->opt->tasks_category_add_button, "clicked", G_CALLBACK (tasks_category_add_cb), appGUI);
 
-	appGUI->opt->tasks_category_remove_button = utl_gui_create_button (GTK_STOCK_REMOVE, OSMO_STOCK_BUTTON_REMOVE, FALSE);
+	appGUI->opt->tasks_category_remove_button = gtk_button_new_from_icon_name ("list-remove", GTK_ICON_SIZE_BUTTON);
 	gtk_widget_set_sensitive (appGUI->opt->tasks_category_remove_button, FALSE);
-	gtk_table_attach (GTK_TABLE (table), appGUI->opt->tasks_category_remove_button, 2, 3, 3, 4,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), appGUI->opt->tasks_category_remove_button, 2, 3, 1, 1);
 	g_signal_connect (appGUI->opt->tasks_category_remove_button, "clicked", G_CALLBACK (tasks_category_remove_cb), appGUI);
 }
 
@@ -565,64 +555,58 @@ static void
 create_reminder_options_section (GtkWidget *reminder_opt_vbox, GUI *appGUI)
 {
 	GtkWidget *table, *label, *spinbutton, *entry, *valid_hbox;
-	GtkObject *adjustment;
+	GtkAdjustment *adjustment;
 	gchar *str;
 	gint i = 0;
 
-	table = gtk_table_new (3, 4, FALSE);
+	table = gtk_grid_new ();
 	gtk_box_pack_start (GTK_BOX (reminder_opt_vbox), table, FALSE, FALSE, 0);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 4);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 8);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 4);
+	gtk_grid_set_row_spacing (GTK_GRID (table), 8);
 
 	label = utl_gui_create_label ("%s:", _("Postpone time"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), label, 0, i, 1, 1);
 
 	adjustment = gtk_adjustment_new (0, 0, 1440, 1, 10, 0);
 	spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 1, 0);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton), TRUE);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), config.postpone_time);
-	gtk_table_attach (GTK_TABLE (table), spinbutton, 1, 2, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), spinbutton, 1, i, 1, 1);
 	g_signal_connect (G_OBJECT (spinbutton), "value-changed", G_CALLBACK (postpone_time_changed_cb), appGUI);
 	appGUI->opt->postpone_time_spinbutton = spinbutton;
 
 	str = g_strdup_printf ("%s (%s)", _("minutes"), _("0 for disable"));
 	label = gtk_label_new (str);
 	g_free (str);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 2, 3, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_widget_set_valign(label, GTK_ALIGN_START);
+	gtk_widget_set_halign(label, GTK_ALIGN_CENTER);
+	gtk_grid_attach (GTK_GRID (table), label, 2, i, 1, 1);
 
 	i++;
 	label = utl_gui_create_label ("%s:", _("Repeat sound alarm"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), label, 0, i, 1, 1);
 
 	adjustment = gtk_adjustment_new (0, 0, 100, 1, 10, 0);
 	spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 1, 0);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton), TRUE);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), config.sound_alarm_repeat);
-	gtk_table_attach (GTK_TABLE (table), spinbutton, 1, 2, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), spinbutton, 1, i, 1, 1);
 	g_signal_connect (G_OBJECT (spinbutton), "value-changed", G_CALLBACK (sound_alarm_repeat_changed_cb), appGUI);
 	appGUI->opt->sound_alarm_repeat_spinbutton = spinbutton;
 
 	str = g_strdup_printf ("%s (%s)", _("times"), _("0 for disable"));
 	label = gtk_label_new (str);
 	g_free (str);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 2, 3, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_widget_set_valign(label, GTK_ALIGN_START);
+	gtk_widget_set_halign(label, GTK_ALIGN_CENTER);
+	gtk_grid_attach (GTK_GRID (table), label, 2, i, 1, 1);
 
 	i++;
 	label = utl_gui_create_label ("%s:", _("Global notification command"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), label, 0, i, 1, 1);
 
-	valid_hbox = gtk_hbox_new (FALSE, 2);
-	gtk_table_attach (GTK_TABLE (table), valid_hbox, 1, 3, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (GTK_FILL), 0, 0);
+	valid_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
+	gtk_grid_attach (GTK_GRID (table), valid_hbox, 1, i, 2, 1);
 
 	entry = gtk_entry_new ();
 	gtk_entry_set_text (GTK_ENTRY (entry), config.global_notification_command);
@@ -644,7 +628,7 @@ tsk_create_preferences_page (GtkWidget *notebook, GUI *appGUI)
 {
 	GtkWidget *vbox_top, *vbox_icon, *vbox, *scrolledwindow;
 
-	vbox_top = gtk_vbox_new (FALSE, VBOX_SPACING);
+	vbox_top = gtk_box_new (GTK_ORIENTATION_VERTICAL, VBOX_SPACING);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox_top), BORDER_WIDTH);
 	scrolledwindow = utl_gui_insert_in_scrolled_window (vbox_top, GTK_SHADOW_ETCHED_IN);
 	gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow), 2);
