@@ -33,9 +33,6 @@ enum {
 };
 
 gboolean tsk_check_tasks           (guint32 julian_start, guint32 julian_end, gint type, GUI *appGUI);
-void     tsk_tasks_foreach         (guint32 julian_start, guint32 julian_end, gboolean (*ttfunc)(), GUI *appGUI);
-gint     tsk_get_tasks_num         (guint32 julian, gboolean check_only, gboolean show_done, gint hidden_category, GUI *appGUI);
-char *   tsk_get_tasks_str         (guint32 julian, gboolean show_done, gint hidden_category, GUI *appGUI);
 
 gboolean      tsk_get_category_state    (gchar *category_name, gint type, GUI *appGUI);
 gchar *       tsk_get_priority_text     (gint index);
