@@ -703,6 +703,19 @@ utl_xml_put_strn (gchar *name, gchar *string, gint buffer_size, xmlNodePtr node)
     g_snprintf (buffer, buffer_size, "%s", string);
     xmlNewTextChild (node, NULL, (const xmlChar *) name, (xmlChar *) buffer);
 }
+/*------------------------------------------------------------------------------*/
+void
+utl_xml_write_doc(const char *filename, xmlDocPtr doc) {
+    gchar *tmp_filename = g_strconcat(filename, ".tmp", NULL);
+
+    if (xmlSaveFormatFileEnc(tmp_filename, doc, "utf-8", 1) == -1) {
+        g_warning("Failed to write a file %s", filename);
+    } else if (g_rename(tmp_filename, filename) == -1) {
+        g_warning("Failed to replace the written file %s", filename);
+    }
+
+    g_free(tmp_filename);
+}
 
 /*------------------------------------------------------------------------------*/
 
@@ -992,16 +1005,25 @@ utl_free_list (GList *list, GDestroyNotify free_func) {
 /*------------------------------------------------------------------------------*/
 #ifdef HAVE_LIBWEBKIT
 WebKitWebView *
-utl_create_webkit_web_view() {
+utl_create_webkit_web_view(GUI *appGUI) {
     WebKitSettings *settings;
     WebKitWebView *view;
+    WebKitUserContentManager *manager;
+    WebKitUserStyleSheet *stylesheet;
     settings = webkit_settings_new();
 
+    manager = webkit_user_content_manager_new();
+    if (appGUI->stylesheet) {
+        stylesheet = webkit_user_style_sheet_new(appGUI->stylesheet, WEBKIT_USER_CONTENT_INJECT_ALL_FRAMES, WEBKIT_USER_STYLE_LEVEL_USER, NULL, NULL);
+        webkit_user_content_manager_add_style_sheet(manager, stylesheet);
+    }
+
     webkit_settings_set_enable_javascript(settings, FALSE);
     webkit_settings_set_enable_plugins(settings, FALSE);
     webkit_settings_set_enable_java(settings, FALSE);
 
-    view = WEBKIT_WEB_VIEW(webkit_web_view_new_with_settings(settings));
+    view = WEBKIT_WEB_VIEW(webkit_web_view_new_with_user_content_manager(manager));
+    webkit_web_view_set_settings(view, settings);
     webkit_web_view_set_editable(view, FALSE);
     return view;
 }
