@@ -103,10 +103,10 @@ void        utl_gui_foreach_selected                (GtkTreeSelection *selection
 GtkTreeIter utl_gui_get_first_selection_iter        (GtkTreeSelection *selection, GtkTreeModel **model);
 void        utl_gui_convert_color_to_string         (GdkRGBA *color, gchar *string);
 void        utl_gui_convert_color_alpha_to_string   (GdkRGBA *color, gchar *string, gint *alpha);
-#ifdef HAVE_GTKSPELL
-void        utl_gui_attach_spell_check              (GtkTextView* text);
-void        utl_gui_dettach_spell_check             (GtkTextView* text);
-#endif /* HAVE_GTKSPELL */
+#ifdef HAVE_GSPELL
+GspellTextView* utl_gui_create_spell_check_textview  (GtkTextView *textview, gboolean enable_by_default);
+void        utl_gui_set_enable_spell_check          (GspellTextView* text, gboolean enable);
+#endif /* HAVE_GSPELL */
 
 #endif /* _UTILS_GUI_H */
 
